@@ -787,10 +787,12 @@ void TracePartFunction::update()
   _calledContexts  = 0;
   _callingContexts = 0;
 
+  // To calculate context counts, we just use first real event type (FIXME?)
+  EventType* e = data() ? data()->eventTypes()->realType(0) : 0;
+
   // calculate additional cost metrics
   foreach(TracePartCall* caller, _partCallers) {
-    // FIXME
-    if (caller->subCost(0)>0)
+    if (e && (caller->subCost(e) >0))
       _calledContexts++;
 
     SubCost c = caller->callCount();
@@ -799,8 +801,7 @@ void TracePartFunction::update()
     }
   }
   foreach(TracePartCall* calling, _partCallings) {
-    // FIXME
-    if (calling->subCost(0)>0)
+    if (e && (calling->subCost(e)>0))
       _callingContexts++;
 
     SubCost c = calling->callCount();
@@ -814,8 +815,7 @@ void TracePartFunction::update()
   if (_partLines.count()>0) {
     ProfileCostArray::clear();
 
-    TracePartLine* line;
-    for (line = _partLines.first(); line; line = _partLines.next())
+    foreach(TracePartLine* line, _partLines)
       addCost(line);
   }
 #else
@@ -1898,7 +1898,7 @@ QString TraceFunction::prettyName() const
       res = QString();
       int d = 0;
       for(int i=0;i<_name.length();i++) {
-          switch(_name[i].toAscii()) {
+          switch(_name[i].toLatin1()) {
           case '<':
               if (d<=0) res.append(_name[i]);
               d++;
@@ -1952,7 +1952,7 @@ QString TraceFunction::formattedName() const
     QString rich("<b>");
     int d = 0;
     for(int i=0;i<_name.length();i++) {
-        switch(_name[i].toAscii()) {
+        switch(_name[i].toLatin1()) {
         case '&':
             rich.append("&amp;");
             break;
@@ -2338,17 +2338,18 @@ void TraceFunction::update()
   _callingContexts = 0;
   clear();
 
+  // To calculate context counts, we just use first real event type (FIXME?)
+  EventType* e = data() ? data()->eventTypes()->realType(0) : 0;
+
   // context count is NOT the sum of part contexts
   foreach(TraceCall *caller, _callers) {
-      // FIXME
-      if (caller->subCost(0) >0)
+      if (e && (caller->subCost(e) >0))
           _calledContexts++;
       _calledCount += caller->callCount();
   }
 
   foreach(TraceCall* callee, _callings) {
-      // FIXME
-      if (callee->subCost(0) >0)
+      if (e && (callee->subCost(e) >0))
           _callingContexts++;
       _callingCount += callee->callCount();
   }
@@ -2434,14 +2435,16 @@ void TraceFunction::cycleDFS(int d, int& pNo, TraceFunction** pTop)
    * percent of the cost of the function.
    * FIXME: Which cost type to use for this heuristic ?!
    */
+  Q_ASSERT((data() != 0) && (data()->eventTypes()->realCount()>0));
+  EventType* e = data()->eventTypes()->realType(0);
 
   SubCost base = 0;
   if (_callers.count()>0) {
       foreach(TraceCall* caller, _callers)
-	  if (caller->subCost(0) > base)
-	      base = caller->subCost(0);
+          if (caller->subCost(e) > base)
+              base = caller->subCost(e);
   }
-  else base = inclusive()->subCost(0);
+  else base = inclusive()->subCost(e);
 
   SubCost cutLimit = SubCost(base * GlobalConfig::cycleCut());
 
@@ -2451,7 +2454,7 @@ void TraceFunction::cycleDFS(int d, int& pNo, TraceFunction** pTop)
              pNo, qPrintable(prettyName()));
       qDebug("%s       Cum. %s, Max Caller %s, cut limit %s",
              qPrintable(QString().fill(' ', d)),
-             qPrintable(inclusive()->subCost(0).pretty()),
+             qPrintable(inclusive()->subCost(e).pretty()),
              qPrintable(base.pretty()),
              qPrintable(cutLimit.pretty()));
   }
@@ -2460,11 +2463,11 @@ void TraceFunction::cycleDFS(int d, int& pNo, TraceFunction** pTop)
     TraceFunction* called = callee->called();
 
       // cycle cut heuristic
-      if (callee->subCost(0) < cutLimit) {
+      if (callee->subCost(e) < cutLimit) {
 	  if (0) qDebug("%s       Cut call to %s (cum. %s)",
 			qPrintable(QString().fill(' ', d)),
 			qPrintable(called->prettyName()),
-			qPrintable(callee->subCost(0).pretty()));
+			qPrintable(callee->subCost(e).pretty()));
 
 	  continue;
       }
@@ -3068,23 +3071,6 @@ TraceData::TraceData(Logger* l)
     init();
 }
 
-TraceData::TraceData(const QString& base)
-    : ProfileCostArray(ProfileContext::context(ProfileContext::Data))
-{
-    _logger = 0;
-
-    init();
-    load(base);
-}
-
-TraceData::TraceData(QIODevice* file, const QString& filename)
-    : ProfileCostArray(ProfileContext::context(ProfileContext::Data))
-{
-    _logger = 0;
-    init();
-    load(file, filename);
-}
-
 void TraceData::init()
 {
   _functionCycleCount = 0;
@@ -3135,75 +3121,56 @@ bool partLessThan(const TracePart* p1, const TracePart* p2)
 }
 
 /**
- * Two cases:
- * - <base> is a directory: Load first profile data file available
- * - <base> is a file name without part/thread suffixes
+ * Load a list of files.
+ * If only one file is given, it is assumed to be a prefix, and all
+ * existing files with that prefix are loaded.
  *
  * Returns 0 if nothing found to load
  */
-int TraceData::load(const QString& base)
+int TraceData::load(QStringList files)
 {
-  bool baseExisting = true;
+    if (files.isEmpty()) return 0;
 
-  _traceName = base;
-  QFileInfo finfo(base);
-  QString file = finfo.fileName();
-  QDir dir = finfo.dir();
+    _traceName = files[0];
+    if (files.count() == 1) {
+        QFileInfo finfo(_traceName);
+        QString prefix = finfo.fileName();
+        QDir dir = finfo.dir();
+        if (finfo.isDir()) {
+            prefix = "callgrind.out";
+            _traceName += "/callgrind.out";
+        }
 
-  if (!finfo.exists()) {
-    baseExisting = false;
-  }
-  else if (finfo.isDir()) {
-      // search for first profile data file in directory
-      dir = QDir(base);
+        files = dir.entryList(QStringList() << prefix + "*", QDir::Files);
+        QStringList::Iterator it = files.begin();
+        for (; it != files.end(); ++it ) {
+            *it = dir.path() + "/" + *it;
+        }
+    }
 
-      QStringList prefixList;
-      prefixList << "callgrind.out" << "cachegrind.out";
-      for ( QStringList::const_iterator it = prefixList.constBegin();
-	    it != prefixList.constEnd(); ++it ) {
-        file = *it;
+    if (files.isEmpty()) {
+        _traceName += ' ' + QObject::tr("(not found)");
+        return 0;
+    }
 
-	// search for ".pid"
-	QStringList strList = dir.entryList(QStringList() << file+".*", QDir::Files);
-	if (strList.count()>0) {
-	  int l = file.length();
-	  file = strList.first();
-	  l++;
-	  while(file[l] >= '0' && file[l] <= '9') l++;
-	  file = file.left(l);
-	  break;
-	}
-      }
+    QStringList::const_iterator it;
+    int partsLoaded = 0;
+    for (it = files.constBegin(); it != files.constEnd(); ++it ) {
+        QFile file(*it);
+        partsLoaded += internalLoad(&file, *it);
+    }
+    if (partsLoaded == 0) return 0;
 
-      _traceName = dir.path() + '/' + file;
-  }
+    qSort(_parts.begin(), _parts.end(), partLessThan);
+    invalidateDynamicCost();
+    updateFunctionCycles();
 
-  QStringList strList;
-  strList += dir.entryList(QStringList() << file+".*" << file+"-*", QDir::Files);
+    return partsLoaded;
+}
 
-  baseExisting = QFile::exists(_traceName);
-  if (baseExisting)
-      strList << file;
-
-  if (strList.count() == 0) {
-      _traceName = base + '/' + file + ' ' + QObject::tr("(not found)");
-      return 0;
-  }
-
-  QStringList::const_iterator it;
-  int partsLoaded = 0;
-  for (it = strList.constBegin(); it != strList.constEnd(); ++it ) {
-      QString filename = QString("%1/%2").arg(dir.path()).arg(*it);
-      QFile file(filename);
-      partsLoaded += internalLoad(&file, filename);
-  }
-  if (partsLoaded == 0) return 0;
-
-  qSort(_parts.begin(), _parts.end(), partLessThan);
-  invalidateDynamicCost();
-  updateFunctionCycles();
-
-  return partsLoaded;
+int TraceData::load(QString file)
+{
+    return load(QStringList(file));
 }
 
 int TraceData::load(QIODevice* file, const QString& filename)
