@@ -867,7 +867,7 @@ void QCGTopLevel::exportGraph()
 
 #ifdef Q_OS_UNIX
     // shell commands only work in UNIX
-    QString cmd = QString("(dot %1 -Tps > %2.ps; kghostview %3.ps)&")
+    QString cmd = QString("(dot %1 -Tps > %2.ps; xdg-open %3.ps)&")
 	.arg(n).arg(n).arg(n);
     if (::system(QFile::encodeName( cmd ))<0)
 	qDebug() << "QCGTopLevel::exportGraph: can not run " << cmd;
