@@ -22,10 +22,6 @@
 
 #include "kcursor.h"
 
-#ifdef __GNUC__
-// Will remove this again very soon, Alex
-#warning This warning is just for testing LABELS in cmake/cdash
-#endif
 
 namespace Okteta {
 
