@@ -1,7 +1,7 @@
 /*
  *    This file is part of the Okteta Kasten module, made within the KDE community.
  *
- *    Copyright 2012  Alex Richardson <alex.richardson@gmx.de>
+ *    Copyright 2012, 2013  Alex Richardson <alex.richardson@gmx.de>
  *
  *    This library is free software; you can redistribute it and/or
  *    modify it under the terms of the GNU Lesser General Public
@@ -42,8 +42,18 @@
 #include "view/structures/datatypes/structuredatainformation.h"
 #include "view/structures/datatypes/uniondatainformation.h"
 #include "view/structures/script/scripthandler.h"
+#include "view/structures/script/classes/arrayscriptclass.h"
+#include "view/structures/script/classes/primitivescriptclass.h"
+#include "view/structures/script/classes/structunionscriptclass.h"
+#include "view/structures/script/classes/stringscriptclass.h"
+#include "view/structures/script/classes/enumscriptclass.h"
+#include "view/structures/script/classes/bitfieldscriptclass.h"
+#include "view/structures/script/classes/pointerscriptclass.h"
 #include "view/structures/script/scriptengineinitializer.h"
+#include "view/structures/script/classes/defaultscriptclass.h"
+#include "view/structures/script/safereference.h"
 #include "view/structures/parsers/scriptvalueconverter.h"
+#include "testutils.h"
 
 class ScriptClassesTest : public QObject
 {
@@ -65,6 +75,10 @@ private Q_SLOTS:
     void checkIterators();
     void testReplaceObject(); //check replacing datatype
     void cleanupTestCase();
+    void testSafeReferenceDeleteObject();
+    void testSafePrimitiveArrayReference();
+    void testScriptValueContents_data();
+    void testScriptValueContents();
 
 private:
     QVector<PropertyPair> commonProperties;
@@ -126,8 +140,7 @@ void ScriptClassesTest::initTestCase()
         PrimitiveDataInformation* prim = PrimitiveFactory::newInstance(
                 QLatin1String("prim"), static_cast<PrimitiveDataTypeEnum>(i), lwc);
         prim->setValue(10);
-        primitives.append(
-                new TopLevelDataInformation(prim, 0, ScriptEngineInitializer::newEngine()));
+        primitives << new TopLevelDataInformation(prim);
     }
 
     enumProperties << primitiveProperties << pair("enumValues", QScriptValue::Undeletable);
@@ -191,6 +204,44 @@ void ScriptClassesTest::initTestCase()
 
 }
 
+Q_DECLARE_METATYPE(QScriptClass*)
+
+static inline void scriptValueContentsAddRow(const char* tag, DataInformation* data, QScriptClass* cls) {
+    QTest::newRow(tag) << data << cls;
+}
+
+void ScriptClassesTest::testScriptValueContents_data()
+{
+    QTest::addColumn<DataInformation*>("data");
+    QTest::addColumn<QScriptClass*>("scriptClass");
+
+    scriptValueContentsAddRow("struct", structData,
+            structDataTop->scriptHandler()->handlerInfo()->mStructUnionClass.data());
+    scriptValueContentsAddRow("union", unionData,
+            unionDataTop->scriptHandler()->handlerInfo()->mStructUnionClass.data());
+    scriptValueContentsAddRow("array", arrayData,
+            arrayDataTop->scriptHandler()->handlerInfo()->mArrayClass.data());
+    scriptValueContentsAddRow("string", stringData,
+            stringDataTop->scriptHandler()->handlerInfo()->mStringClass.data());
+}
+
+void ScriptClassesTest::testScriptValueContents()
+{
+    QFETCH(DataInformation*, data);
+    QFETCH(QScriptClass*, scriptClass);
+
+    QScriptValue val = data->toScriptValue(data->topLevelDataInformation());
+    QVERIFY(val.isValid());
+    QVERIFY(val.isObject());
+    QCOMPARE(val.scriptClass(), scriptClass);
+    QVERIFY(val.data().isVariant());
+    QVariant variant = val.data().toVariant();
+    QVERIFY(variant.isValid());
+    QVERIFY(variant.canConvert<SafeReference>());
+    QCOMPARE(variant.value<SafeReference>().data(), data);
+    QCOMPARE(DefaultScriptClass::toDataInformation(val), data);
+}
+
 void ScriptClassesTest::checkProperties(const QVector<PropertyPair>& expected,
         DataInformation* data, const char* tag)
 {
@@ -213,7 +264,7 @@ void ScriptClassesTest::checkProperties(const QVector<PropertyPair>& expected,
         for (int i = 0; i < qMin(foundProperties.size(), expected.size()); ++i)
         {
             if (foundProperties.at(i) != expected.at(i))
-                qWarning() << tag << ":" << foundProperties.at(i) << "!=" << expected.at(i);
+                qWarning() << tag << ":" << foundProperties.at(i) << ", but expected:" << expected.at(i);
             QCOMPARE(foundProperties.at(i).first, expected.at(i).first);
             QCOMPARE(foundProperties.at(i).second, expected.at(i).second);
         }
@@ -335,16 +386,63 @@ void ScriptClassesTest::testReplaceObject()
     QCOMPARE(main->childAt(0)->name(), QString(QLatin1String("innerStruct")));
     QCOMPARE(main->childAt(1)->name(), QString(QLatin1String("innerArray")));
     QCOMPARE(main->childAt(2)->name(), QString(QLatin1String("innerPointer")));
-
-
 }
 
+static const QString invalidObjectError = QLatin1String("ReferenceError: Attempting to access an invalid object");
+
+void ScriptClassesTest::testSafePrimitiveArrayReference()
+{
+    QVERIFY(arrayData->arrayType()->isPrimitive());
+    QVERIFY(arrayData->length() > 2);
+    arrayDataTop->logger()->setLogToStdOut(true);
+    QScriptEngine* eng = arrayDataTop->scriptEngine();
+    eng->pushContext();
+    eng->currentContext()->activationObject().setProperty(QLatin1String("myArray"),
+            arrayData->toScriptValue(arrayDataTop.data()));
+    arrayDataTop->scriptHandler()->handlerInfo()->setMode(ScriptHandlerInfo::Updating);
+    QScriptValue v0 = eng->evaluate(QLatin1String("myArray[0]"));
+    QCOMPARE(Utils::property(v0, "name").toString(), QString::number(0));
+    QVERIFY(DefaultScriptClass::toDataInformation(v0) != 0);
+    //access index 1 -> index 0 should become invalid, since there is only one object available
+    QScriptValue v1 = eng->evaluate(QLatin1String("myArray[1]"));
+    QVERIFY(DefaultScriptClass::toDataInformation(v1) != 0);
+    QVERIFY(DefaultScriptClass::toDataInformation(v0) == 0);
+    QVERIFY(!eng->hasUncaughtException());
+    QCOMPARE(Utils::property(v1, "name").toString(), QString::number(1));
+    QVERIFY(!eng->hasUncaughtException());
+    QCOMPARE(Utils::property(v0, "name").toString(), invalidObjectError);
+    QVERIFY(!eng->hasUncaughtException());
+    //even after accessing a v0 property (which will fail), v1 properties should remain valid
+    QCOMPARE(Utils::property(v1, "name").toString(), QString::number(1));
+    QVERIFY(!eng->hasUncaughtException());
+    arrayDataTop->scriptHandler()->handlerInfo()->setMode(ScriptHandlerInfo::None);
+    eng->popContext();
+}
+
+void ScriptClassesTest::testSafeReferenceDeleteObject()
+{
+    QScopedPointer<TopLevelDataInformation> top(Utils::evalAndParse("struct({bar: uint8()}).set({name: 'foo'});"));
+    QVERIFY(top->actualDataInformation()->isStruct());
+    top->scriptHandler()->handlerInfo()->setMode(ScriptHandlerInfo::TaggedUnionSelection);
+    QScriptValue val = top->actualDataInformation()->toScriptValue(top.data());
+    QScriptValue name = Utils::property(val, "name");
+    QVERIFY(name.isValid());
+    QVERIFY(!name.isError());
+    QCOMPARE(name.toString(), QString(QLatin1String("foo")));
+    top->setActualDataInformation(new DummyDataInformation(0));
+    //val should now point to an invalid reference -> accessing name should throw an error
+    name = Utils::property(val, "name");
+    QVERIFY(name.isValid());
+    QVERIFY(name.isError());
+    QCOMPARE(name.toString(), invalidObjectError);
+}
 
 void ScriptClassesTest::cleanupTestCase()
 {
     qDeleteAll(primitives);
 }
 
+
 QTEST_MAIN(ScriptClassesTest)
 
 #include "scriptclassestest.moc"
