@@ -72,6 +72,16 @@ bool DataInformationBase::isString() const
     return false;
 }
 
+bool DataInformationBase::isPointer() const
+{
+    return false;
+}
+
+bool DataInformationBase::isTaggedUnion() const
+{
+    return false;
+}
+
 TopLevelDataInformation* DataInformationBase::asTopLevel()
 {
     //multiple inheritance -> we can't use reinterpret_cast -> we have to include the file
