@@ -25,13 +25,13 @@
 #include <QScriptValue>
 
 #include "../booldatainformation.h"
+#include "../../../../poddecoder/typeeditors/uintspinbox.h"
 
 
 QString BoolBitfieldDataInformation::valueString() const
 {
-    if (!mWasAbleToRead)
-        return i18nc("invalid value (out of range)", "&lt;invalid&gt;");
-    return BoolDataInformation<quint64>::valueString(mValue.ulongValue);
+    Q_ASSERT(mWasAbleToRead);
+    return BoolDataInformationMethods<quint64>::staticValueString(mValue.ulongValue);
 }
 
 QWidget* BoolBitfieldDataInformation::createEditWidget(QWidget* parent) const
