@@ -24,24 +24,16 @@
 
 #include "abstractbitfielddatainformation.h"
 
+#include <KLocalizedString>
+
 class SignedBitfieldDataInformation : public AbstractBitfieldDataInformation
 {
+    DATAINFORMATION_CLONE(SignedBitfieldDataInformation, AbstractBitfieldDataInformation) {}
 public:
-    SignedBitfieldDataInformation(QString name, BitCount32 width, DataInformation* parent = 0)
-            : AbstractBitfieldDataInformation(name, width, parent)
-    {
-    }
-    virtual ~SignedBitfieldDataInformation()
-    {
-    }
-protected:
-    SignedBitfieldDataInformation(const SignedBitfieldDataInformation& d)
-            : AbstractBitfieldDataInformation(d)
-    {
-    }
-private:
-public:
-    DATAINFORMATION_CLONE(SignedBitfield)
+    SignedBitfieldDataInformation(const QString& name, BitCount32 width, DataInformation* parent = 0)
+            : AbstractBitfieldDataInformation(name, width, parent) {}
+    virtual ~SignedBitfieldDataInformation() {}
+    virtual AllPrimitiveTypes fromVariant(const QVariant& variant, bool* ok) const;
 
     QString typeName() const;
     virtual QString valueString() const;
