@@ -27,14 +27,10 @@
 #include "../poddecoder/typeeditors/uintspinbox.h"
 #include "../uintdatainformation.h"
 
-
-
-
 QString UnsignedBitfieldDataInformation::valueString() const
 {
-    if (!mWasAbleToRead)
-        return i18nc("invalid value (out of range)", "&lt;invalid&gt;");
-    return UIntDataInformation<quint64>::valueString(mValue.ulongValue);
+    Q_ASSERT(mWasAbleToRead);
+    return UIntDataInformationMethods<quint64>::staticValueString(mValue.ulongValue);
 }
 
 QWidget* UnsignedBitfieldDataInformation::createEditWidget(QWidget* parent) const
