@@ -24,14 +24,7 @@
 #include <QScriptValue>
 #include <KLineEdit>
 #include <KGlobal>
-
-QString CharDataInformation::valueString() const
-{
-    if (!mWasAbleToRead)
-        return i18nc("invalid value (out of range)", "&lt;invalid&gt;");
-    //TODO char codec
-    return valueString(mValue);
-}
+#include <KLocale>
 
 namespace {
     QString charString(quint8 value)
@@ -55,7 +48,7 @@ namespace {
     }
 }
 
-QString CharDataInformation::valueString(quint8 value)
+QString CharDataInformationMethods::staticValueString(quint8 value)
 {
     QString charStr = charString(value);
     if (Kasten2::StructViewPreferences::showCharNumericalValue())
@@ -75,22 +68,12 @@ QString CharDataInformation::valueString(quint8 value)
     return charStr;
 }
 
-QWidget* CharDataInformation::staticCreateEditWidget(QWidget* parent)
+QWidget* CharDataInformationMethods::staticCreateEditWidget(QWidget* parent)
 {
     return new KLineEdit(parent);
 }
 
-QWidget* CharDataInformation::createEditWidget(QWidget* parent) const
-{
-    return staticCreateEditWidget(parent);
-}
-
-QVariant CharDataInformation::dataFromWidget(const QWidget* w) const
-{
-    return staticDataFromWidget(w);
-}
-
-QVariant CharDataInformation::staticDataFromWidget(const QWidget* w)
+QVariant CharDataInformationMethods::staticDataFromWidget(const QWidget* w)
 {
     //TODO fix this code!!
     const KLineEdit* edit = dynamic_cast<const KLineEdit*> (w);
@@ -148,13 +131,7 @@ QVariant CharDataInformation::staticDataFromWidget(const QWidget* w)
     return QVariant();
 }
 
-void CharDataInformation::setWidgetData(QWidget* w) const
-{
-    return staticSetWidgetData(mValue, w);
-}
-
-
-void CharDataInformation::staticSetWidgetData(quint8 value, QWidget* w)
+void CharDataInformationMethods::staticSetWidgetData(quint8 value, QWidget* w)
 {
     KLineEdit* edit = dynamic_cast<KLineEdit*> (w);
     if (edit)
@@ -166,17 +143,7 @@ void CharDataInformation::staticSetWidgetData(quint8 value, QWidget* w)
     }
 }
 
-AllPrimitiveTypes CharDataInformation::qVariantToAllPrimitiveTypes(
-        const QVariant& value) const
-{
-    if (!value.isValid())
-        kDebug() << "invalid QVariant passed.";
-
-    //This is fine since all the values are unsigned
-    return AllPrimitiveTypes(value.toUInt());
-}
-
-int CharDataInformation::displayBase()
+int CharDataInformationMethods::displayBase()
 {
     int base = Kasten2::StructViewPreferences::charDisplayBase();
     if (base == Kasten2::StructViewPreferences::EnumCharDisplayBase::Binary)
@@ -186,23 +153,7 @@ int CharDataInformation::displayBase()
     return 10; //safe default value
 }
 
-AllPrimitiveTypes CharDataInformation::value() const
-{
-    return AllPrimitiveTypes(mValue);
-}
-
-
-void CharDataInformation::setValue(AllPrimitiveTypes newVal)
-{
-    mValue = newVal.ubyteValue;
-}
-
-QScriptValue CharDataInformation::valueAsQScriptValue() const
-{
-    return asScriptValue(mValue, 0, 0);
-}
-
-QScriptValue CharDataInformation::asScriptValue(quint8 value, QScriptEngine* engine, ScriptHandlerInfo* handler)
+QScriptValue CharDataInformationMethods::asScriptValue(quint8 value, QScriptEngine* engine, ScriptHandlerInfo* handler)
 {
     Q_UNUSED(engine);
     Q_UNUSED(handler);
