@@ -24,32 +24,15 @@
 #include <QScriptValue>
 #include <KDoubleNumInput>
 #include <KGlobal>
+#include <KLocale>
 
-
-QString DoubleDataInformation::valueString() const
-{
-    if (!mWasAbleToRead)
-        return i18nc("invalid value (out of range)", "&lt;invalid&gt;");
-    return valueString(mValue);
-}
-
-QWidget* DoubleDataInformation::createEditWidget(QWidget* parent) const
-{
-    return staticCreateEditWidget(parent);
-}
-
-QWidget* DoubleDataInformation::staticCreateEditWidget(QWidget* parent)
+QWidget* DoubleDataInformationMethods::staticCreateEditWidget(QWidget* parent)
 {
     KDoubleNumInput* ret = new KDoubleNumInput(parent);
     return ret;
 }
 
-QVariant DoubleDataInformation::dataFromWidget(const QWidget* w) const
-{
-    return staticDataFromWidget(w);
-}
-
-QVariant DoubleDataInformation::staticDataFromWidget(const QWidget* w)
+QVariant DoubleDataInformationMethods::staticDataFromWidget(const QWidget* w)
 {
     const KDoubleNumInput* spin = dynamic_cast<const KDoubleNumInput*> (w);
     Q_CHECK_PTR(spin);
@@ -58,12 +41,8 @@ QVariant DoubleDataInformation::staticDataFromWidget(const QWidget* w)
     return QVariant();
 }
 
-void DoubleDataInformation::setWidgetData(QWidget* w) const
-{
-    staticSetWidgetData(mValue, w);
-}
 
-void DoubleDataInformation::staticSetWidgetData(double value, QWidget* w)
+void DoubleDataInformationMethods::staticSetWidgetData(double value, QWidget* w)
 {
     KDoubleNumInput* spin = dynamic_cast<KDoubleNumInput*> (w);
     Q_CHECK_PTR(spin);
@@ -71,35 +50,14 @@ void DoubleDataInformation::staticSetWidgetData(double value, QWidget* w)
         spin->setValue(value);
 }
 
-AllPrimitiveTypes DoubleDataInformation::qVariantToAllPrimitiveTypes(const QVariant& value) const
-{
-    return AllPrimitiveTypes(value.toDouble());
-}
-
-AllPrimitiveTypes DoubleDataInformation::value() const
-{
-    return AllPrimitiveTypes(mValue);
-}
-
-void DoubleDataInformation::setValue(AllPrimitiveTypes newVal)
-{
-    mValue = newVal.doubleValue;
-}
-
-QScriptValue DoubleDataInformation::asScriptValue(double value, QScriptEngine* engine, ScriptHandlerInfo* handler)
+QScriptValue DoubleDataInformationMethods::asScriptValue(double value, QScriptEngine* engine, ScriptHandlerInfo* handler)
 {
     Q_UNUSED(engine);
     Q_UNUSED(handler);
     return QScriptValue(value);
 }
 
-
-QScriptValue DoubleDataInformation::valueAsQScriptValue() const
-{
-    return asScriptValue(mValue, 0, 0);
-}
-
-QString DoubleDataInformation::valueString(double value)
+QString DoubleDataInformationMethods::staticValueString(double value)
 {
 	if (Kasten2::StructViewPreferences::localeAwareFloatFormatting())
 		return KGlobal::locale()->formatNumber(value, Kasten2::StructViewPreferences::floatPrecision());
