@@ -22,12 +22,11 @@
 
 #include "scriptfileparser.h"
 
-#include "../structuredefinitionfile.h"
+#include "scriptvalueconverter.h"
 #include "../datatypes/topleveldatainformation.h"
 #include "../datatypes/dummydatainformation.h"
 #include "../script/scriptengineinitializer.h"
 #include "../script/scriptlogger.h"
-#include "../script/scriptvalueconverter.h"
 
 #include <QScriptEngine>
 
@@ -86,7 +85,7 @@ DataInformation* ScriptFileParser::convert(ScriptLogger* logger, QScriptEngine*
     QScriptValue result = initMethod.call(thisObj, args);
     if (result.isError())
     {
-        logger->error(result) << "Exception occurred while calling init()";
+        logger->error() << "Exception occurred while calling init()";
         return new DummyDataInformation(0, mPluginName);
     }
 
