@@ -31,6 +31,7 @@
 #include "../../parsers/scriptvalueconverter.h"
 #include "../scriptlogger.h"
 #include "../scripthandlerinfo.h"
+#include "../safereference.h"
 
 #include <KDebug>
 
@@ -46,7 +47,6 @@ DefaultScriptClass::DefaultScriptClass(QScriptEngine* engine, ScriptHandlerInfo*
     s_datatype = engine->toStringHandle(ParserStrings::PROPERTY_DATATYPE);
     s_updateFunc = engine->toStringHandle(ParserStrings::PROPERTY_UPDATE_FUNC);
     s_validationFunc = engine->toStringHandle(ParserStrings::PROPERTY_VALIDATION_FUNC);
-    qScriptRegisterMetaType<DataInfPtr>(engine, DefaultScriptClass::toScriptValue, DefaultScriptClass::fromScriptValue);
 
     //TODO remove, every subclass should have proto
     mDefaultPrototype = engine->newObject();
@@ -67,16 +67,18 @@ DefaultScriptClass::~DefaultScriptClass()
 {
 }
 
-QScriptValue DefaultScriptClass::toScriptValue(QScriptEngine* eng, const DataInfPtr& data)
+DataInformation* DefaultScriptClass::toDataInformation(const QScriptValue& obj)
 {
-    QScriptValue obj = eng->newObject();
-    obj.setData(eng->newVariant(QVariant::fromValue(data)));
-    return obj;
-}
-
-void DefaultScriptClass::fromScriptValue(const QScriptValue& obj, DataInfPtr& data)
-{
-    data = qvariant_cast<DataInfPtr>(obj.data().toVariant());
+    if (!obj.scriptClass())
+        return 0;
+    Q_ASSERT(obj.data().isVariant());
+    const QVariant variant = obj.data().toVariant();
+    if (variant.isValid() && variant.canConvert<SafeReference>() && variant.userType() == qMetaTypeId<SafeReference>())
+    {
+        const SafeReference& ref = *reinterpret_cast<const SafeReference*>(variant.constData());
+        return ref.data();
+    }
+    return 0;
 }
 
 QScriptClass::QueryFlags DefaultScriptClass::queryProperty(const QScriptValue& object,
@@ -84,10 +86,12 @@ QScriptClass::QueryFlags DefaultScriptClass::queryProperty(const QScriptValue& o
 {
     const ScriptHandlerInfo::Mode mode = mHandlerInfo->mode();
     Q_ASSERT(mode != ScriptHandlerInfo::None);
-    DataInformation* data = qscriptvalue_cast<DataInformation*>(object.data());
+    DataInformation* data = toDataInformation(object);
     if (!data)
     {
-        mHandlerInfo->logger()->error() << "could not cast data from" << object.toString();
+        mHandlerInfo->logger()->error() << "could not cast data from" << object.data().toString();
+        engine()->currentContext()->throwError(QScriptContext::ReferenceError,
+                QLatin1String("Attempting to access an invalid object"));
         return 0;
     }
     if (name == s_valid || name == s_validationError)
@@ -117,6 +121,8 @@ QScriptClass::QueryFlags DefaultScriptClass::queryProperty(const QScriptValue& o
     else
     {
         data->logError() << "could not find property with name" << name.toString();
+        engine()->currentContext()->throwError(QScriptContext::ReferenceError,
+                QLatin1String("Could not find property with name ") + name.toString());
         return 0;
     }
 }
@@ -124,11 +130,12 @@ QScriptClass::QueryFlags DefaultScriptClass::queryProperty(const QScriptValue& o
 QScriptValue DefaultScriptClass::property(const QScriptValue& object, const QScriptString& name, uint id)
 {
     Q_ASSERT(mHandlerInfo->mode() != ScriptHandlerInfo::None);
-    DataInformation* data = qscriptvalue_cast<DataInformation*>(object.data());
+    DataInformation* data = toDataInformation(object);
     if (!data)
     {
-        mHandlerInfo->logger()->error() << "could not cast data from" << object.toString();
-        return QScriptValue();
+        mHandlerInfo->logger()->error() << "could not cast data from" << object.data().toString();
+        return engine()->currentContext()->throwError(QScriptContext::ReferenceError,
+                QLatin1String("Attempting to access an invalid object"));
     }
     if (name == s_valid)
     {
@@ -176,16 +183,18 @@ QScriptValue DefaultScriptClass::property(const QScriptValue& object, const QScr
     else
     {
         data->logError() << "could not find property with name" << name.toString();
-        return engine()->undefinedValue();
+        return engine()->currentContext()->throwError(QScriptContext::ReferenceError,
+                QLatin1String("Cannot read property ") + name.toString());
     }
 }
 
 void DefaultScriptClass::setDataType(const QScriptValue& value, DataInformation* data)
 {
-    DataInformation* thisObj = qscriptvalue_cast<DataInformation*>(engine()->currentContext()->thisObject().data());
+    DataInformation* thisObj = toDataInformation(engine()->currentContext()->thisObject());
     Q_CHECK_PTR(thisObj);
     const bool isThisObj = thisObj == data;
-    if (data->hasBeenUpdated())
+    //this object always has mHasBeenUpdated set just before calling updateFunc, so in that case it is okay
+    if (data->hasBeenUpdated() && !isThisObj)
     {
         //this element has already been updated (and probably read, replacing it could cause crazy errors
         data->logError() << "Attempting to replace an already updated object. This could cause errors."
@@ -208,6 +217,7 @@ void DefaultScriptClass::setDataType(const QScriptValue& value, DataInformation*
     bool replaced = false;
     if (parent->isTopLevel())
     {
+        Q_ASSERT(isThisObj); //we can only do this if we are currently at the top level element
         parent->asTopLevel()->setActualDataInformation(newType);
         replaced = true;
     }
@@ -244,7 +254,6 @@ void DefaultScriptClass::setDataType(const QScriptValue& value, DataInformation*
     if (replaced)
     {
         top->setChildDataChanged();
-        newType->mHasBeenUpdated = true;
         //if the current object was "this" in javascript we have to replace it
         if (isThisObj)
             engine()->currentContext()->setThisObject(newType->toScriptValue(engine(), mHandlerInfo));
@@ -253,16 +262,19 @@ void DefaultScriptClass::setDataType(const QScriptValue& value, DataInformation*
     {
         delete newType; //could not set new type
     }
+    newType->mHasBeenUpdated = true;
 }
 
 void DefaultScriptClass::setProperty(QScriptValue& object, const QScriptString& name, uint id, const QScriptValue& value)
 {
     const ScriptHandlerInfo::Mode mode = mHandlerInfo->mode();
     Q_ASSERT(mode != ScriptHandlerInfo::None);
-    DataInformation* data = qscriptvalue_cast<DataInformation*>(object.data());
+    DataInformation* data = toDataInformation(object);
     if (!data)
     {
-        mHandlerInfo->logger()->error() << "could not cast data from" << object.toString();
+        mHandlerInfo->logger()->error() << "could not cast data from" << object.data().toString();
+        engine()->currentContext()->throwError(QScriptContext::ReferenceError,
+                QLatin1String("Attempting to access an invalid object"));
         return;
     }
     if (mode == ScriptHandlerInfo::Validating)
@@ -321,6 +333,8 @@ void DefaultScriptClass::setProperty(QScriptValue& object, const QScriptString&
         else
         {
             data->logError() << "could not set property with name" << name.toString();
+            engine()->currentContext()->throwError(QScriptContext::ReferenceError,
+                QLatin1String("Cannot write property ") + name.toString());
         }
     }
 }
@@ -330,10 +344,12 @@ QScriptValue::PropertyFlags DefaultScriptClass::propertyFlags(const QScriptValue
     QScriptValue::PropertyFlags result;
     const ScriptHandlerInfo::Mode mode = mHandlerInfo->mode();
     Q_ASSERT(mode != ScriptHandlerInfo::None);
-    DataInformation* data = qscriptvalue_cast<DataInformation*>(object.data());
+    DataInformation* data = toDataInformation(object);
     if (!data)
     {
-        mHandlerInfo->logger()->error() << "could not cast data from" << object.toString();
+        mHandlerInfo->logger()->error() << "could not cast data from" << object.data().toString();
+        engine()->currentContext()->throwError(QScriptContext::ReferenceError,
+                QLatin1String("Attempting to access an invalid object"));
         return 0;
     }
     if (name == s_valid || name == s_validationError)
@@ -366,7 +382,7 @@ QScriptValue DefaultScriptClass::prototype() const
 
 QScriptValue DefaultScriptClass::Default_proto_toString(QScriptContext* ctx, QScriptEngine* eng)
 {
-    DataInformation* data = qscriptvalue_cast<DataInformation*>(ctx->thisObject().data());
+    DataInformation* data = toDataInformation(ctx->thisObject());
     if (!data)
     {
         kWarning() << "could not cast data";
@@ -378,14 +394,13 @@ QScriptValue DefaultScriptClass::Default_proto_toString(QScriptContext* ctx, QSc
 
 QScriptClassPropertyIterator* DefaultScriptClass::newIterator(const QScriptValue& object)
 {
-    return new DefaultscriptClassIterator(object, mIterableProperties, engine());
+    return new DefaultscriptClassIterator(object, this);
 }
 
-DefaultscriptClassIterator::DefaultscriptClassIterator(const QScriptValue& object, const DefaultScriptClass::PropertyInfoList& list,
-                                                       QScriptEngine* engine)
-    : QScriptClassPropertyIterator(object), mCurrent(-1), mList(list), mEngine(engine)
+DefaultscriptClassIterator::DefaultscriptClassIterator(const QScriptValue& object, DefaultScriptClass* cls)
+        : QScriptClassPropertyIterator(object), mCurrent(-1), mClass(cls)
 {
-    DataInformation* data = qscriptvalue_cast<DataInformation*>(object.data());
+    DataInformation* data = DefaultScriptClass::toDataInformation(object);
     Q_CHECK_PTR(data);
     mData = data;
 }
@@ -396,7 +411,7 @@ DefaultscriptClassIterator::~DefaultscriptClassIterator()
 
 bool DefaultscriptClassIterator::hasNext() const
 {
-    return mCurrent < mList.size() - 1;
+    return mCurrent < mClass->mIterableProperties.size() - 1;
 }
 
 bool DefaultscriptClassIterator::hasPrevious() const
@@ -406,41 +421,41 @@ bool DefaultscriptClassIterator::hasPrevious() const
 
 QScriptString DefaultscriptClassIterator::name() const
 {
-    Q_ASSERT(mCurrent >= 0 && (uint)mCurrent < mList.size() + mData->childCount());
-    if (mCurrent < 0 || (uint)mCurrent >= mList.size() + mData->childCount())
+    Q_ASSERT(mCurrent >= 0 && (uint)mCurrent < mClass->mIterableProperties.size() + mData->childCount());
+    if (mCurrent < 0 || (uint)mCurrent >= mClass->mIterableProperties.size() + mData->childCount())
         return QScriptString();
-    if (mCurrent < mList.size())
-        return mList.at(mCurrent).first;
-    int index = mCurrent - mList.size();
+    if (mCurrent < mClass->mIterableProperties.size())
+        return mClass->mIterableProperties.at(mCurrent).first;
+    int index = mCurrent - mClass->mIterableProperties.size();
     Q_ASSERT(index >= 0);
     DataInformation* child = mData->childAt(index);
-    return mEngine->toStringHandle(child->name());
+    return mClass->engine()->toStringHandle(child->name());
 }
 
 QScriptValue::PropertyFlags DefaultscriptClassIterator::flags() const
 {
-    Q_ASSERT(mCurrent >= 0 && (uint)mCurrent < mList.size() + mData->childCount());
-    if (mCurrent < 0 || (uint)mCurrent >= mList.size() + mData->childCount())
+    Q_ASSERT(mCurrent >= 0 && (uint)mCurrent < mClass->mIterableProperties.size() + mData->childCount());
+    if (mCurrent < 0 || (uint)mCurrent >= mClass->mIterableProperties.size() + mData->childCount())
         return 0;
-    if (mCurrent < mList.size())
-        return mList.at(mCurrent).second;
+    if (mCurrent < mClass->mIterableProperties.size())
+        return mClass->propertyFlags(object(), mClass->mIterableProperties.at(mCurrent).first, id());
     return QScriptValue::ReadOnly;
 }
 
 uint DefaultscriptClassIterator::id() const
 {
-    Q_ASSERT(mCurrent >= 0 && (uint)mCurrent < mList.size() + mData->childCount());
-    if (mCurrent < 0 || (uint)mCurrent >= mList.size() + mData->childCount())
+    Q_ASSERT(mCurrent >= 0 && (uint)mCurrent < mClass->mIterableProperties.size() + mData->childCount());
+    if (mCurrent < 0 || (uint)mCurrent >= mClass->mIterableProperties.size() + mData->childCount())
         return 0;
     //only children have an id assigned
-    if (mCurrent < mList.size())
+    if (mCurrent < mClass->mIterableProperties.size())
         return 0;
-    return mCurrent - mList.size() + 1;
+    return mCurrent - mClass->mIterableProperties.size() + 1;
 }
 
 void DefaultscriptClassIterator::next()
 {
-    Q_ASSERT(mCurrent == -1 || (uint)mCurrent < mList.size() + mData->childCount());
+    Q_ASSERT(mCurrent == -1 || (uint)mCurrent < mClass->mIterableProperties.size() + mData->childCount());
     mCurrent++;
 }
 
@@ -452,7 +467,7 @@ void DefaultscriptClassIterator::previous()
 
 void DefaultscriptClassIterator::toBack()
 {
-    mCurrent = mList.size() + mData->childCount();
+    mCurrent = mClass->mIterableProperties.size() + mData->childCount();
 }
 
 void DefaultscriptClassIterator::toFront()
