@@ -138,7 +138,9 @@ QScriptValue StructUnionScriptClass::additionalProperty(const DataInformation* d
         {
             dataW->logError() << "attempting to access out of bounds child: index was" << pos
                     << ", maximum is" << (data->childCount() - 1);
-            return engine()->undefinedValue();
+            return engine()->currentContext()->throwError(QScriptContext::RangeError,
+                QString(QLatin1String("Attempting to access struct index %1, but length is %2")).arg(
+                    QString::number(pos), QString::number(data->childCount())));
         }
         else
         {
@@ -195,7 +197,7 @@ QScriptValue StructUnionScriptClass::prototype() const
 
 QScriptValue StructUnionScriptClass::StructUnion_proto_toString(QScriptContext* ctx, QScriptEngine* eng)
 {
-    DataInformation* data = qscriptvalue_cast<DataInformation*>(ctx->thisObject().data());
+    DataInformation* data = toDataInformation(ctx->thisObject());
     if (!data)
     {
         kWarning() << "could not cast data";
@@ -219,7 +221,7 @@ QScriptValue StructUnionScriptClass::StructUnion_proto_child(QScriptContext* ctx
                         QLatin1String("(struct/union).child(name) argument has to be a string"));
         return QScriptValue::UndefinedValue;
     }
-    DataInformation* data = qscriptvalue_cast<DataInformation*>(ctx->thisObject().data());
+    DataInformation* data = toDataInformation(ctx->thisObject());
     if (!data)
     {
         kDebug() << "could not cast data";
@@ -243,7 +245,7 @@ QScriptValue StructUnionScriptClass::StructUnion_proto_setChildren(QScriptContex
         return ctx->throwError(QScriptContext::RangeError,
                                QLatin1String("(struct/union).child(children) needs one argument"));
     }
-    DataInformation* data = qscriptvalue_cast<DataInformation*>(ctx->thisObject().data());
+    DataInformation* data = toDataInformation(ctx->thisObject());
     if (!data)
     {
         kDebug() << "could not cast data";
