@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -16,7 +16,7 @@
  * @param name   The name of the Actor.
  * @param id     The unique id to assign to this Actor.
  */
-UMLActor::UMLActor(const QString & name, Uml::IDType id)
+UMLActor::UMLActor(const QString & name, Uml::ID::Type id)
   : UMLCanvasObject(name, id)
 {
     init();
