@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2011                                               *
+ *   copyright (C) 2003-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -35,29 +35,29 @@ DEBUG_REGISTER(UMLAssociation)
 /**
  * Sets up an association.
  * A new unique ID is assigned internally.
- * @param type    The AssociationType to construct.
+ * @param type    The AssociationType::Enum to construct.
  * @param roleA   Pointer to the UMLObject in role A.
  * @param roleB   Pointer to the UMLObject in role B.
  */
-UMLAssociation::UMLAssociation( Uml::AssociationType type,
+UMLAssociation::UMLAssociation( Uml::AssociationType::Enum type,
                                 UMLObject * roleA, UMLObject * roleB )
   : UMLObject("")
 {
     init(type, roleA, roleB);
 
-    m_pRole[Uml::A]->setID( UniqueID::gen() );
-    m_pRole[Uml::B]->setID( UniqueID::gen() );
+    m_pRole[RoleType::A]->setID( UniqueID::gen() );
+    m_pRole[RoleType::B]->setID( UniqueID::gen() );
 }
 
 /**
  * Constructs an association - for loading only.
  * This constructor should not normally be used as it constructs
  * an incomplete association (i.e. the role objects are missing.)
- * @param type   The AssociationType to construct.
+ * @param type   The AssociationType::Enum to construct.
  *               Default: Unknown.
  */
-UMLAssociation::UMLAssociation( Uml::AssociationType type)
-  : UMLObject("", Uml::id_Reserved)
+UMLAssociation::UMLAssociation( Uml::AssociationType::Enum type)
+  : UMLObject("", Uml::ID::Reserved)
 {
     init(type, NULL, NULL);
 }
@@ -67,17 +67,17 @@ UMLAssociation::UMLAssociation( Uml::AssociationType type)
  */
 UMLAssociation::~UMLAssociation( )
 {
-    if (m_pRole[A] == NULL) {
+    if (m_pRole[RoleType::A] == NULL) {
         uError() << "UMLAssociation destructor: m_pRole[A] is NULL already";
     } else {
-        delete m_pRole[A];
-        m_pRole[A] = NULL;
+        delete m_pRole[RoleType::A];
+        m_pRole[RoleType::A] = NULL;
     }
-    if (m_pRole[B] == NULL) {
+    if (m_pRole[RoleType::B] == NULL) {
         uError() << "UMLAssociation destructor: m_pRole[B] is NULL already";
     } else {
-        delete m_pRole[B];
-        m_pRole[B] = NULL;
+        delete m_pRole[RoleType::B];
+        m_pRole[RoleType::B] = NULL;
     }
 }
 
@@ -92,15 +92,15 @@ bool UMLAssociation::operator==(const UMLAssociation &rhs) const
     return ( UMLObject::operator== ( rhs ) &&
              m_AssocType == rhs.m_AssocType &&
              m_Name == rhs.m_Name &&
-             m_pRole[A] == rhs.m_pRole[A] &&
-             m_pRole[B] == rhs.m_pRole[B] );
+             m_pRole[RoleType::A] == rhs.m_pRole[RoleType::A] &&
+             m_pRole[RoleType::B] == rhs.m_pRole[RoleType::B] );
 }
 
 /**
- * Returns the AssociationType of the UMLAssociation.
- * @return  The AssociationType of the UMLAssociation.
+ * Returns the AssociationType::Enum of the UMLAssociation.
+ * @return  The AssociationType::Enum of the UMLAssociation.
  */
-Uml::AssociationType UMLAssociation::getAssocType() const
+Uml::AssociationType::Enum UMLAssociation::getAssocType() const
 {
     return m_AssocType;
 }
@@ -111,18 +111,18 @@ Uml::AssociationType UMLAssociation::getAssocType() const
 QString UMLAssociation::toString() const
 {
     QString string;
-    if(m_pRole[A])
+    if(m_pRole[RoleType::A])
     {
-        string += m_pRole[A]->object()->name();
+        string += m_pRole[RoleType::A]->object()->name();
         string += ':';
-        string += m_pRole[A]->name();
+        string += m_pRole[RoleType::A]->name();
     }
-    string += ':' + m_AssocType.toStringI18n() + ':';
-    if(m_pRole[B])
+    string += ':' + Uml::AssociationType::toStringI18n(m_AssocType) + ':';
+    if(m_pRole[RoleType::B])
     {
-        string += m_pRole[B]->object( )->name();
+        string += m_pRole[RoleType::B]->object( )->name();
         string += ':';
-        string += m_pRole[B]->name();
+        string += m_pRole[RoleType::B]->name();
     }
     return string;
 }
@@ -136,11 +136,11 @@ QString UMLAssociation::toString() const
  */
 bool UMLAssociation::resolveRef()
 {
-    bool successA = getUMLRole(A)->resolveRef();
-    bool successB = getUMLRole(B)->resolveRef();
+    bool successA = getUMLRole(RoleType::A)->resolveRef();
+    bool successB = getUMLRole(RoleType::B)->resolveRef();
     if (successA && successB) {
-        UMLObject *objA = getUMLRole(A)->object();
-        UMLObject *objB = getUMLRole(B)->object();
+        UMLObject *objA = getUMLRole(RoleType::A)->object();
+        UMLObject *objB = getUMLRole(RoleType::B)->object();
         // Check if need to change the assoc type to Realization
         if (isRealization(objA, objB)) {
             m_AssocType = Uml::AssociationType::Realization;
@@ -160,44 +160,44 @@ void UMLAssociation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
     if (m_AssocType == Uml::AssociationType::Generalization) {
         QDomElement assocElement = UMLObject::save("UML:Generalization", qDoc);
         assocElement.setAttribute( "discriminator", "" );
-        assocElement.setAttribute( "child", ID2STR(getObjectId(A)) );
-        assocElement.setAttribute( "parent", ID2STR(getObjectId(B)) );
+        assocElement.setAttribute( "child", ID2STR(getObjectId(RoleType::A)) );
+        assocElement.setAttribute( "parent", ID2STR(getObjectId(RoleType::B)) );
         qElement.appendChild( assocElement );
         return;
     }
     if (m_AssocType == Uml::AssociationType::Realization) {
         QDomElement assocElement = UMLObject::save("UML:Abstraction", qDoc);
-        assocElement.setAttribute( "client", ID2STR(getObjectId(A)) );
-        assocElement.setAttribute( "supplier", ID2STR(getObjectId(B)) );
+        assocElement.setAttribute( "client", ID2STR(getObjectId(RoleType::A)) );
+        assocElement.setAttribute( "supplier", ID2STR(getObjectId(RoleType::B)) );
         qElement.appendChild( assocElement );
         return;
     }
     if (m_AssocType == Uml::AssociationType::Dependency) {
         QDomElement assocElement = UMLObject::save("UML:Dependency", qDoc);
-        assocElement.setAttribute( "client", ID2STR(getObjectId(A)) );
-        assocElement.setAttribute( "supplier", ID2STR(getObjectId(B)) );
+        assocElement.setAttribute( "client", ID2STR(getObjectId(RoleType::A)) );
+        assocElement.setAttribute( "supplier", ID2STR(getObjectId(RoleType::B)) );
         qElement.appendChild( assocElement );
         return;
     }
     if (m_AssocType == Uml::AssociationType::Child2Category ) {
         QDomElement assocElement = UMLObject::save("UML:Child2Category", qDoc);
-        assocElement.setAttribute( "client", ID2STR(getObjectId(A)) );
-        assocElement.setAttribute( "supplier", ID2STR(getObjectId(B)) );
+        assocElement.setAttribute( "client", ID2STR(getObjectId(RoleType::A)) );
+        assocElement.setAttribute( "supplier", ID2STR(getObjectId(RoleType::B)) );
         qElement.appendChild( assocElement );
         return;
     }
     if (m_AssocType == Uml::AssociationType::Category2Parent ) {
         QDomElement assocElement = UMLObject::save("UML:Category2Parent", qDoc);
-        assocElement.setAttribute( "client", ID2STR(getObjectId(A)) );
-        assocElement.setAttribute( "supplier", ID2STR(getObjectId(B)) );
+        assocElement.setAttribute( "client", ID2STR(getObjectId(RoleType::A)) );
+        assocElement.setAttribute( "supplier", ID2STR(getObjectId(RoleType::B)) );
         qElement.appendChild( assocElement );
         return;
     }
 
     QDomElement associationElement = UMLObject::save("UML:Association", qDoc);
     QDomElement connElement = qDoc.createElement("UML:Association.connection");
-    getUMLRole(A)->saveToXMI (qDoc, connElement);
-    getUMLRole(B)->saveToXMI (qDoc, connElement);
+    getUMLRole(RoleType::A)->saveToXMI (qDoc, connElement);
+    getUMLRole(RoleType::B)->saveToXMI (qDoc, connElement);
     associationElement.appendChild (connElement);
     qElement.appendChild( associationElement );
 }
@@ -208,7 +208,7 @@ void UMLAssociation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
  */
 bool UMLAssociation::load( QDomElement & element )
 {
-    if (id() == Uml::id_None)
+    if (id() == Uml::ID::None)
         return false; // old style XMI file. No real info in this association.
 
     UMLDoc * doc = UMLApp::app()->document();
@@ -219,10 +219,10 @@ bool UMLAssociation::load( QDomElement & element )
         m_AssocType == Uml::AssociationType::Child2Category ||
         m_AssocType == Uml::AssociationType::Category2Parent
         ) {
-        for (unsigned r = Uml::A; r <= Uml::B; ++r) {
+        for (unsigned r = RoleType::A; r <= RoleType::B; ++r) {
             const QString fetch = (m_AssocType == Uml::AssociationType::Generalization ?
-                                   r == Uml::A ? "child" : "parent"
-                       : r == Uml::A ? "client" : "supplier");
+                                   r == RoleType::A ? "child" : "parent"
+                       : r == RoleType::A ? "client" : "supplier");
             QString roleIdStr = element.attribute(fetch, "");
             if (roleIdStr.isEmpty()) {
                 // Might be given as a child node instead - see below.
@@ -231,20 +231,20 @@ bool UMLAssociation::load( QDomElement & element )
 
             // set umlobject of role if possible (else defer resolution)
             obj[r] = doc->findObjectById(STR2ID(roleIdStr));
-            Uml::Role_Type role = (Uml::Role_Type)r;
+            Uml::RoleType::Enum role = Uml::RoleType::fromInt(r);
             if (obj[r] == NULL) {
                 m_pRole[role]->setSecondaryId(roleIdStr);  // defer to resolveRef()
             } else {
                 m_pRole[role]->setObject(obj[r]);
                 if (m_pUMLPackage == NULL) {
-                    Uml::ModelType mt = Model_Utils::convert_OT_MT(obj[r]->baseType());
+                    Uml::ModelType::Enum mt = Model_Utils::convert_OT_MT(obj[r]->baseType());
                     m_pUMLPackage = doc->rootFolder(mt);
                     DEBUG(DBG_SRC) << "assoctype " << m_AssocType
-                        << ": setting model type " << mt;
+                        << ": setting model type " << Uml::ModelType::toString(mt);
                 }
             }
         }
-        if (obj[A] == NULL || obj[B] == NULL) {
+        if (obj[RoleType::A] == NULL || obj[RoleType::B] == NULL) {
             for (QDomNode node = element.firstChild(); !node.isNull();
                     node = node.nextSibling()) {
                 if (node.isComment())
@@ -275,15 +275,15 @@ bool UMLAssociation::load( QDomElement & element )
                 // Since we know for sure that we're dealing with a non
                 // umbrello file, use deferred resolution unconditionally.
                 if (UMLDoc::tagEq(tag, "child") || UMLDoc::tagEq(tag, "subtype") || UMLDoc::tagEq(tag, "client")) {
-                    getUMLRole(A)->setSecondaryId(idStr);
+                    getUMLRole(RoleType::A)->setSecondaryId(idStr);
                 } else {
-                    getUMLRole(B)->setSecondaryId(idStr);
+                    getUMLRole(RoleType::B)->setSecondaryId(idStr);
                 }
             }
         }
 
         // it is a realization if either endpoint is an interface
-        if (isRealization(obj[A], obj[B])) {
+        if (isRealization(obj[RoleType::A], obj[RoleType::B])) {
             m_AssocType = Uml::AssociationType::Realization;
         }
         return true;
@@ -319,7 +319,7 @@ bool UMLAssociation::load( QDomElement & element )
             uWarning() << "unknown child (A) tag " << tag;
             return false;
         }
-        if (! getUMLRole(A)->loadFromXMI(tempElement))
+        if (! getUMLRole(RoleType::A)->loadFromXMI(tempElement))
             return false;
         // Load role B.
         QDomNode nodeB = nodeA.nextSibling();
@@ -336,13 +336,13 @@ bool UMLAssociation::load( QDomElement & element )
             uWarning() << "unknown child (B) tag " << tag;
             return false;
         }
-        if (! getUMLRole(B)->loadFromXMI(tempElement))
+        if (! getUMLRole(RoleType::B)->loadFromXMI(tempElement))
             return false;
 
         if (m_pUMLPackage == NULL) {
-            Uml::ModelType mt = Model_Utils::convert_OT_MT(getObject(B)->baseType());
+            Uml::ModelType::Enum mt = Model_Utils::convert_OT_MT(getObject(RoleType::B)->baseType());
             m_pUMLPackage = doc->rootFolder(mt);
-            DEBUG(DBG_SRC) << "setting model type " << mt;
+            DEBUG(DBG_SRC) << "setting model type " << Uml::ModelType::toString(mt);
         }
 
         // setting the association type:
@@ -355,7 +355,7 @@ bool UMLAssociation::load( QDomElement & element )
         // is not complete, so we need to finish the analysis here.
 
         // find self-associations
-        if (m_AssocType == Uml::AssociationType::Association && getObjectId(A) == getObjectId(B))
+        if (m_AssocType == Uml::AssociationType::Association && getObjectId(RoleType::A) == getObjectId(RoleType::B))
             m_AssocType = Uml::AssociationType::Association_Self;
 
         // fall-back default type
@@ -368,7 +368,7 @@ bool UMLAssociation::load( QDomElement & element )
 
     // From here on it's old-style stuff.
     QString assocTypeStr = element.attribute( "assoctype", "-1" );
-    Uml::AssociationType assocType = Uml::AssociationType::Unknown;
+    Uml::AssociationType::Enum assocType = Uml::AssociationType::Unknown;
     if (assocTypeStr[0] >= 'a' && assocTypeStr[0] <= 'z') {
         // In an earlier version, the natural assoctype names were saved.
         const QString assocTypeString[] = {
@@ -401,25 +401,25 @@ bool UMLAssociation::load( QDomElement & element )
             if (assocTypeStr == assocTypeString[index])
                 break;
         if (index < arraySize)
-            assocType = Uml::AssociationType::Value(index);
+            assocType = Uml::AssociationType::fromInt(index);
     } else {
         int assocTypeNum = assocTypeStr.toInt();
         if (assocTypeNum < (int)Uml::AssociationType::Generalization ||   // first enum
             assocTypeNum > (int)Uml::AssociationType::Relationship) {     // last enum
-            uWarning() << "bad assoctype of UML:AssociationType " << ID2STR(id());
+            uWarning() << "bad assoctype of UML:AssociationType::Enum " << ID2STR(id());
             return false;
         }
-        assocType = Uml::AssociationType::Value(assocTypeNum);
+        assocType = Uml::AssociationType::fromInt(assocTypeNum);
     }
     setAssociationType( assocType );
 
-    Uml::IDType roleAObjID = STR2ID(element.attribute( "rolea", "-1" ));
-    Uml::IDType roleBObjID = STR2ID(element.attribute( "roleb", "-1" ));
+    Uml::ID::Type roleAObjID = STR2ID(element.attribute( "rolea", "-1" ));
+    Uml::ID::Type roleBObjID = STR2ID(element.attribute( "roleb", "-1" ));
     if (assocType == Uml::AssociationType::Aggregation ||
         assocType == Uml::AssociationType::Composition) {
         // Flip roles to compensate for changed diamond logic in AssociationLine.
         // For further explanations see AssociationWidget::loadFromXMI.
-        Uml::IDType tmp = roleAObjID;
+        Uml::ID::Type tmp = roleAObjID;
         roleAObjID = roleBObjID;
         roleBObjID = tmp;
     }
@@ -428,23 +428,23 @@ bool UMLAssociation::load( QDomElement & element )
     UMLObject * objB = doc->findObjectById(roleBObjID);
 
     if(objA)
-        getUMLRole(A)->setObject(objA);
+        getUMLRole(RoleType::A)->setObject(objA);
     else
         return false;
 
     if(objB)
-        getUMLRole(B)->setObject(objB);
+        getUMLRole(RoleType::B)->setObject(objB);
     else
         return false;
 
-    setMultiplicity(element.attribute( "multia", "" ), A);
-    setMultiplicity(element.attribute( "multib", "" ), B);
+    setMultiplicity(element.attribute( "multia", "" ), RoleType::A);
+    setMultiplicity(element.attribute( "multib", "" ), RoleType::B);
 
-    setRoleName(element.attribute( "namea", "" ), A);
-    setRoleName(element.attribute( "nameb", "" ), B);
+    setRoleName(element.attribute( "namea", "" ), RoleType::A);
+    setRoleName(element.attribute( "nameb", "" ), RoleType::B);
 
-    setRoleDoc(element.attribute( "doca", "" ), A);
-    setRoleDoc(element.attribute( "docb", "" ), B);
+    setRoleDoc(element.attribute( "doca", "" ), RoleType::A);
+    setRoleDoc(element.attribute( "docb", "" ), RoleType::B);
 
     // Visibility defaults to Public if it cant set it here..
     QString visibilityA = element.attribute( "visibilitya", "0");
@@ -452,19 +452,19 @@ bool UMLAssociation::load( QDomElement & element )
     int vis = visibilityA.toInt();
     if (vis >= 200)  // bkwd compat.
         vis -= 200;
-    setVisibility((Uml::Visibility::Value)vis, A);
+    setVisibility((Uml::Visibility::Enum)vis, RoleType::A);
     vis = visibilityB.toInt();
     if (vis >= 200)  // bkwd compat.
         vis -= 200;
-    setVisibility((Uml::Visibility::Value)vis, B);
+    setVisibility((Uml::Visibility::Enum)vis, RoleType::B);
 
     // Changeability defaults to Changeable if it cant set it here..
     QString changeabilityA = element.attribute( "changeabilitya", "0");
     QString changeabilityB = element.attribute( "changeabilityb", "0");
     if (changeabilityA.toInt() > 0)
-        setChangeability(Uml::Changeability(Uml::Changeability::Value(changeabilityA.toInt())), A);
+        setChangeability(Uml::Changeability::fromInt(changeabilityA.toInt()), RoleType::A);
     if (changeabilityB.toInt() > 0)
-        setChangeability(Uml::Changeability(Uml::Changeability::Value(changeabilityB.toInt())), B);
+        setChangeability(Uml::Changeability::fromInt(changeabilityB.toInt()), RoleType::B);
 
     return true;
 }
@@ -473,7 +473,7 @@ bool UMLAssociation::load( QDomElement & element )
  * Returns the UMLObject assigned to the given role.
  * @return  Pointer to the UMLObject in the given role.
  */
-UMLObject* UMLAssociation::getObject(Uml::Role_Type role) const
+UMLObject* UMLAssociation::getObject(Uml::RoleType::Enum role) const
 {
     if (m_pRole[role] == NULL)
         return NULL;
@@ -485,7 +485,7 @@ UMLObject* UMLAssociation::getObject(Uml::Role_Type role) const
  * Shorthand for getObject(role)->ID().
  * @return  ID of the UMLObject in the given role.
  */
-Uml::IDType UMLAssociation::getObjectId(Uml::Role_Type role) const
+Uml::ID::Type UMLAssociation::getObjectId(Uml::RoleType::Enum role) const
 {
     UMLRole *roleObj = m_pRole[role];
     UMLObject *o = roleObj->object();
@@ -493,7 +493,7 @@ Uml::IDType UMLAssociation::getObjectId(Uml::Role_Type role) const
         QString auxID = roleObj->secondaryId();
         if (auxID.isEmpty()) {
             uError() << "role " << role << ": getObject returns NULL";
-            return Uml::id_None;
+            return Uml::ID::None;
         } else {
             DEBUG(DBG_SRC) << "role " << role << ": using secondary ID " << auxID;
             return STR2ID(auxID);
@@ -507,7 +507,7 @@ Uml::IDType UMLAssociation::getObjectId(Uml::Role_Type role) const
  * CURRENTLY UNUSED.
  * @return  ID of the UMLObject of the given role.
  */
-Uml::IDType UMLAssociation::getRoleId(Role_Type role) const
+Uml::ID::Type UMLAssociation::getRoleId(RoleType::Enum role) const
 {
     return m_pRole[role]->id();
 }
@@ -515,7 +515,7 @@ Uml::IDType UMLAssociation::getRoleId(Role_Type role) const
 /**
  * Returns the changeability.
  */
-Uml::Changeability UMLAssociation::changeability(Uml::Role_Type role) const
+Uml::Changeability::Enum UMLAssociation::changeability(Uml::RoleType::Enum role) const
 {
     return m_pRole[role]->changeability();
 }
@@ -524,7 +524,7 @@ Uml::Changeability UMLAssociation::changeability(Uml::Role_Type role) const
  * Returns the Visibility of the given role.
  * @return  Visibility of the given role.
  */
-Uml::Visibility UMLAssociation::getVisibility(Uml::Role_Type role) const
+Uml::Visibility::Enum UMLAssociation::visibility(Uml::RoleType::Enum role) const
 {
     return m_pRole[role]->visibility();
 }
@@ -533,7 +533,7 @@ Uml::Visibility UMLAssociation::getVisibility(Uml::Role_Type role) const
  * Returns the multiplicity assigned to the given role.
  * @return  The multiplicity assigned to the given role.
  */
-QString UMLAssociation::getMultiplicity(Uml::Role_Type role) const
+QString UMLAssociation::getMultiplicity(Uml::RoleType::Enum role) const
 {
     return m_pRole[role]->multiplicity();
 }
@@ -542,7 +542,7 @@ QString UMLAssociation::getMultiplicity(Uml::Role_Type role) const
  * Returns the name assigned to the role A.
  * @return  The name assigned to the given role.
  */
-QString UMLAssociation::getRoleName(Uml::Role_Type role) const
+QString UMLAssociation::getRoleName(Uml::RoleType::Enum role) const
 {
     return m_pRole[role]->name();
 }
@@ -551,7 +551,7 @@ QString UMLAssociation::getRoleName(Uml::Role_Type role) const
  * Returns the documentation assigned to the given role.
  * @return  Documentation text of given role.
  */
-QString UMLAssociation::getRoleDoc(Uml::Role_Type role) const
+QString UMLAssociation::getRoleDoc(Uml::RoleType::Enum role) const
 {
     return m_pRole[role]->doc();
 }
@@ -560,7 +560,7 @@ QString UMLAssociation::getRoleDoc(Uml::Role_Type role) const
  * Get the underlying UMLRole object for the given role.
  * @return  Pointer to the UMLRole object for the given role.
  */
-UMLRole * UMLAssociation::getUMLRole(Uml::Role_Type role) const
+UMLRole * UMLAssociation::getUMLRole(Uml::RoleType::Enum role) const
 {
     return m_pRole[role];
 }
@@ -584,9 +584,9 @@ bool UMLAssociation::getOldLoadMode() const
 
 /**
  * Sets the assocType of the UMLAssociation.
- * @param assocType The AssociationType of the UMLAssociation.
+ * @param assocType The AssociationType::Enum of the UMLAssociation.
  */
-void UMLAssociation::setAssociationType(Uml::AssociationType assocType)
+void UMLAssociation::setAssociationType(Uml::AssociationType::Enum assocType)
 {
     m_AssocType = assocType;
     if (m_AssocType == Uml::AssociationType::UniAssociation)
@@ -603,9 +603,9 @@ void UMLAssociation::setAssociationType(Uml::AssociationType assocType)
 /**
  * Sets the UMLObject playing the given role in the association.
  * @param obj  Pointer to the UMLObject of the given role.
- * @param role The Uml::Role_Type played by the association
+ * @param role The Uml::RoleType::Enum played by the association
  */
-void UMLAssociation::setObject(UMLObject *obj, Uml::Role_Type role)
+void UMLAssociation::setObject(UMLObject *obj, Uml::RoleType::Enum role)
 {
     m_pRole[role]->setObject(obj);
 }
@@ -613,9 +613,9 @@ void UMLAssociation::setObject(UMLObject *obj, Uml::Role_Type role)
 /**
  * Sets the visibility of the given role of the UMLAssociation.
  * @param value  Visibility of role.
- * @param role   The Uml::Role_Type to which the visibility is being applied
+ * @param role   The Uml::RoleType::Enum to which the visibility is being applied
  */
-void UMLAssociation::setVisibility(Uml::Visibility value, Uml::Role_Type role)
+void UMLAssociation::setVisibility(Visibility::Enum value, Uml::RoleType::Enum role)
 {
     m_pRole[role]->setVisibility(value);
 }
@@ -623,9 +623,9 @@ void UMLAssociation::setVisibility(Uml::Visibility value, Uml::Role_Type role)
 /**
  * Sets the changeability of the given role of the UMLAssociation.
  * @param value     Changeability_Type of the given role.
- * @param role      The Uml::Role_Type to which the changeability is being set
+ * @param role      The Uml::RoleType::Enum to which the changeability is being set
  */
-void UMLAssociation::setChangeability(Uml::Changeability value, Uml::Role_Type role)
+void UMLAssociation::setChangeability(Uml::Changeability::Enum value, Uml::RoleType::Enum role)
 {
     m_pRole[role]->setChangeability(value);
 }
@@ -633,9 +633,9 @@ void UMLAssociation::setChangeability(Uml::Changeability value, Uml::Role_Type r
 /**
  * Sets the multiplicity of the given role of the UMLAssociation.
  * @param multi    The multiplicity of the given role.
- * @param role     The Uml::Role_Type to which the multiplicity is being applied
+ * @param role     The Uml::RoleType::Enum to which the multiplicity is being applied
  */
-void UMLAssociation::setMultiplicity(const QString &multi, Uml::Role_Type role)
+void UMLAssociation::setMultiplicity(const QString &multi, Uml::RoleType::Enum role)
 {
     UMLApp::app()->executeCommand(new CmdChangeMultiplicity(m_pRole[role], multi));
     //m_pRole[role]->setMultiplicity(multi);
@@ -644,9 +644,9 @@ void UMLAssociation::setMultiplicity(const QString &multi, Uml::Role_Type role)
 /**
  * Sets the name of the given role of the UMLAssociation.
  * @param roleName  The name to set for the given role.
- * @param role      The Uml::Role_Type for which to set the name.
+ * @param role      The Uml::RoleType::Enum for which to set the name.
  */
-void UMLAssociation::setRoleName(const QString &roleName, Uml::Role_Type role)
+void UMLAssociation::setRoleName(const QString &roleName, Uml::RoleType::Enum role)
 {
     m_pRole[role]->setName(roleName);
 }
@@ -654,9 +654,9 @@ void UMLAssociation::setRoleName(const QString &roleName, Uml::Role_Type role)
 /**
  * Sets the documentation on the given role in the association.
  * @param doc      The string with the documentation.
- * @param role     The Uml::Role_Type to which the documentation is being applied
+ * @param role     The Uml::RoleType::Enum to which the documentation is being applied
  */
-void UMLAssociation::setRoleDoc(const QString &doc, Uml::Role_Type role)
+void UMLAssociation::setRoleDoc(const QString &doc, Uml::RoleType::Enum role)
 {
     m_pRole[role]->setDoc(doc);
 }
@@ -684,11 +684,11 @@ bool UMLAssociation::isRealization(UMLObject* objA, UMLObject* objB) const
 
 /**
  * Common initializations at construction time.
- * @param type      The AssociationType to represent.
+ * @param type      The AssociationType::Enum to represent.
  * @param roleAObj  Pointer to the role A UMLObject.
  * @param roleBObj  Pointer to the role B UMLObject.
  */
-void UMLAssociation::init(Uml::AssociationType type, UMLObject *roleAObj, UMLObject *roleBObj)
+void UMLAssociation::init(Uml::AssociationType::Enum type, UMLObject *roleAObj, UMLObject *roleBObj)
 {
     m_AssocType = type;
     m_BaseType = ot_Association;
@@ -698,8 +698,8 @@ void UMLAssociation::init(Uml::AssociationType type, UMLObject *roleAObj, UMLObj
     if (!UMLApp::app()->document()->loading()) {
         m_pUMLPackage = UMLApp::app()->document()->currentRoot();
     }
-    m_pRole[Uml::A] = new UMLRole (this, roleAObj, Uml::A);
-    m_pRole[Uml::B] = new UMLRole (this, roleBObj, Uml::B);
+    m_pRole[RoleType::A] = new UMLRole (this, roleAObj, RoleType::A);
+    m_pRole[RoleType::B] = new UMLRole (this, roleBObj, RoleType::B);
 }
 
 #include "association.moc"
