@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -20,7 +20,7 @@ namespace Uml
     class CmdMoveWidget : public QUndoCommand
     {
     public:
-        CmdMoveWidget(UMLWidgetController* wc);
+        explicit CmdMoveWidget(UMLWidgetController* wc);
         ~CmdMoveWidget();
 
         void redo();
