@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2012                                               *
+ *   copyright (C) 2004-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -57,7 +57,7 @@ CPPCodeGenerator::~CPPCodeGenerator()
  * Returns language identifier. In this case "Cpp".
  * @return language identifier
  */
-Uml::ProgrammingLanguage CPPCodeGenerator::language() const
+Uml::ProgrammingLanguage::Enum CPPCodeGenerator::language() const
 {
     return Uml::ProgrammingLanguage::Cpp;
 }
