@@ -44,7 +44,7 @@ void DCodeClassFieldDeclarationBlock::updateContent()
     DCodeClassField * jcf = dynamic_cast<DCodeClassField*>(cf);
     CodeGenerationPolicy * commonpolicy = UMLApp::app()->commonPolicy();
 
-    Uml::Visibility::Value scopePolicy = commonpolicy->getAssociationFieldScope();
+    Uml::Visibility::Enum scopePolicy = commonpolicy->getAssociationFieldScope();
 
     // Set the comment
     QString notes = getParentObject()->doc();
@@ -52,7 +52,7 @@ void DCodeClassFieldDeclarationBlock::updateContent()
 
     // Set the body
     QString staticValue = getParentObject()->isStatic() ? "static " : "";
-    QString scopeStr = getParentObject()->visibility().toString();
+    QString scopeStr = Uml::Visibility::toString(getParentObject()->visibility());
 
     // IF this is from an association, then scope taken as appropriate to policy
     if(!jcf->parentIsAttribute())
@@ -61,7 +61,7 @@ void DCodeClassFieldDeclarationBlock::updateContent()
         case Uml::Visibility::Public:
         case Uml::Visibility::Private:
         case Uml::Visibility::Protected:
-              scopeStr = Uml::Visibility::toString((Uml::Visibility::Value) scopePolicy);
+              scopeStr = Uml::Visibility::toString(scopePolicy);
             break;
         default:
         case Uml::Visibility::FromParent:
