@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2005                                                     *
+ *  copyright (C) 2005-2013                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
@@ -20,7 +20,7 @@
  */
 class IDLImport : public NativeImportBase {
 public:
-    IDLImport(CodeImpThread* thread = 0);
+    explicit IDLImport(CodeImpThread* thread = 0);
     virtual ~IDLImport();
 
     bool parseStmt();
