@@ -25,9 +25,12 @@
 
 #include <klocale.h>
 
-#include <QtCore/QRegExp>
-#include <QtCore/QMap>
-#include <QtCore/QList>
+#include <QCoreApplication>
+#include <QDir>
+#include <QFile>
+#include <QList>
+#include <QMap>
+#include <QRegExp>
 
 #include <boost/bind.hpp>
 #include <boost/function.hpp>
@@ -36,6 +39,8 @@
 
 #include "assignFunctor.hpp"
 
+#define PREPROCESSLEXER_DEBUG
+
 #ifdef Q_CC_MSVC
 template <class _Tp>
 struct _Identity : public std::unary_function<_Tp,_Tp> {
@@ -62,7 +67,7 @@ using phoenix::var;
 SkipRule PreprocessLexer::m_SkipRule = nothing_p;
 
 #if defined( KDEVELOP_BGPARSER )
-#include <QtCore/QThread>
+#include <QThread>
 
 class KDevTread: public QThread
 {
@@ -578,13 +583,34 @@ void PreprocessLexer::output(CharIterator p_first, CharIterator p_last)
         m_preprocessedString += *p_first;
 }
 
+/**
+ * dump preprocess file to temporay location
+ */
+void PreprocessLexer::dumpToFile()
+{
+    QString tempPath = QDir::tempPath() + QString("/umbrello-%1").arg(QCoreApplication::applicationPid());
+    QDir d(tempPath);
+    if (!d.exists())
+        d.mkdir(tempPath);
+
+    QString fileName = tempPath + '/' + currentPosition().file.toString().replace(QRegExp("[/:mn]"), "-");
+    QFile f(fileName);
+    if (f.open(QIODevice::WriteOnly | QIODevice::Text)) {
+        QTextStream out(&f);
+        out << m_preprocessedString;
+    }
+}
+
 bool PreprocessLexer::preprocess()
 {
     for (;;) {
         Position start = currentPosition();
         nextLine();
         if (currentPosition() == start) {
-            uError() << "failed to preprocess file" << start;
+#ifdef PREPROCESSLEXER_DEBUG
+            dumpToFile();
+#endif
+            uError() << "preprocess failed" << start;
             return false;
         }
 
