@@ -31,6 +31,7 @@
 #include "model_utils.h"
 #include "uml.h"
 #include "umldoc.h"
+#include "umllistview.h"
 
 //kde includes
 #include <kfiledialog.h>
@@ -39,6 +40,7 @@
 
 //qt includes
 #include <QListWidget>
+#include <QTimer>
 
 /**
  * Constructor.
@@ -47,7 +49,11 @@
 CodeImpStatusPage::CodeImpStatusPage(QWidget *parent)
   : QWizardPage(parent),
     m_workDone(false),
-    m_index(0)
+    m_index(0),
+    m_savedlistViewVisible(false)
+#ifdef ENABLE_IMPORT_THREAD
+  , m_thread(0)
+#endif
 {
     setTitle(i18n("Status of Code Importing Progress"));
     setSubTitle(i18n("Press the button 'Start import' to start the code import.\nCheck the success state for every class."));
@@ -124,6 +130,9 @@ void CodeImpStatusPage::importCode()
 
     UMLDoc* doc = UMLApp::app()->document();
     doc->setLoading(true);
+    // hide list view dockwindow to avoid time consuming update on every insert
+    m_savedlistViewVisible = UMLApp::app()->listView()->parentWidget()->isVisible();
+    UMLApp::app()->listView()->parentWidget()->setVisible(false);
 
     ui_textEditLogger->setHtml(i18np("<b>Code import of 1 file:</b><br>", "<b>Code import of %1 files:</b><br>", m_files.size()));
     m_index = 0;
@@ -163,7 +172,7 @@ void CodeImpStatusPage::importCodeFile(bool noError)
     connect(worker, SIGNAL(messageToLog(QString,QString)), this, SLOT(messageToLog(QString,QString)));
     connect(worker, SIGNAL(messageToApp(QString)), this, SLOT(messageToApp(QString)));
 #ifndef ENABLE_IMPORT_THREAD
-    connect(worker, SIGNAL(finished(bool)), this, SLOT(importCodeFile(bool)));
+    connect(worker, SIGNAL(finished(bool)), this, SLOT(importNextFile(bool)));
     connect(worker, SIGNAL(aborted()), this, SLOT(importCodeStop()));
     worker->run();
     worker->deleteLater();
@@ -176,6 +185,11 @@ void CodeImpStatusPage::importCodeFile(bool noError)
     uDebug() << "****** starting task for " << m_file.fileName();
 }
 
+void CodeImpStatusPage::importNextFile(bool noError)
+{
+    QTimer::singleShot(10, this, SLOT(importCodeFile()));
+}
+
 void CodeImpStatusPage::importCodeFinish()
 {
     UMLDoc* doc = UMLApp::app()->document();
@@ -184,6 +198,7 @@ void CodeImpStatusPage::importCodeFinish()
     // Allowing undo of the whole class importing. I think it eats a lot of memory.
     // Setting the modification, but without allowing undo.
     doc->setModified(true);
+    UMLApp::app()->listView()->parentWidget()->setVisible(m_savedlistViewVisible);
 
     m_workDone = true;
     setFinalPage(true);
@@ -218,6 +233,7 @@ void CodeImpStatusPage::importCodeStop()
     // Allowing undo of the whole class importing. I think it eats a lot of memory.
     // Setting the modification, but without allowing undo.
     doc->setModified(true);
+    UMLApp::app()->listView()->parentWidget()->setVisible(m_savedlistViewVisible);
 
     m_workDone = true;
     setFinalPage(true);
