@@ -127,13 +127,6 @@ void MessageWidgetController::moveWidgetBy(UMLSceneValue diffX, UMLSceneValue di
     }
 
     m_messageWidget->setY(newY);
-
-    if (m_messageWidget->m_sequenceMessageType == Uml::SequenceMessage::Creation) {
-        const UMLSceneValue objWidgetHalfHeight = m_messageWidget->m_pOw[Uml::RoleType::B]->height() / 2;
-        m_messageWidget->m_pOw[Uml::RoleType::B]->UMLWidget::setY(newY - objWidgetHalfHeight);
-    }
-
-    m_messageWidget->moveEvent(0);
 }
 
 /**
