@@ -376,10 +376,10 @@ void UMLWidgetController::mouseReleaseEvent(QGraphicsSceneMouseEvent *me)
     //TODO Copied from old code. Does it really work as intended?
     UMLWidget *bkgnd = m_widget->m_scene->widgetAt(me->scenePos());
     if (bkgnd) {
-        //uDebug() << "setting Z to " << bkgnd->z() + 1;
-        m_widget->setZ(bkgnd->z() + 1);
+        //uDebug() << "setting Z to " << bkgnd->zValue() + 1.0;
+        m_widget->setZValue(bkgnd->zValue() + 1.0);
     } else {
-        m_widget->setZ(0);
+        m_widget->setZValue(0);
     }
 }
 
@@ -679,6 +679,7 @@ void UMLWidgetController::updateSelectionBounds(int diffX, int diffY)
  */
 void UMLWidgetController::resize(QGraphicsSceneMouseEvent *me)
 {
+    // TODO the status message lies for at least MessageWidget which could only be resized vertical
     UMLApp::app()->document()->writeToStatusBar(i18n("Hold shift or ctrl to move in X axis. Hold shift and control to move in Y axis. Right button click to cancel resize."));
 
     m_resized = true;
