@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2012                                               *
+ *   copyright (C) 2003-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -233,7 +233,7 @@ public:
     ~ListPopupMenu();
 
     static UMLObject::ObjectType convert_MT_OT(MenuType mt);
-    static Uml::DiagramType convert_MT_DT(MenuType mt);
+    static Uml::DiagramType::Enum convert_MT_DT(MenuType mt);
 
     static ListPopupMenu* menuFromAction(QAction *action);
 
