@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2011                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -42,15 +42,15 @@
  * @param rt        the return type of the operation
  */
 UMLOperation::UMLOperation(UMLClassifier *parent, const QString& name,
-                           Uml::IDType id, Uml::Visibility s, UMLObject *rt)
+                           Uml::ID::Type id, Uml::Visibility::Enum s, UMLObject *rt)
   : UMLClassifierListItem(parent, name, id)
 {
     if (rt)
         m_returnId = UniqueID::gen();
     else
-        m_returnId = Uml::id_None;
+        m_returnId = Uml::ID::None;
     m_pSecondary = rt;
-    m_Vis = s;
+    m_visibility = s;
     m_BaseType = UMLObject::ot_Operation;
     m_bConst = false;
     m_Code.clear();
@@ -87,7 +87,7 @@ UMLOperation::~UMLOperation()
 void UMLOperation::setType(UMLObject* type)
 {
     UMLClassifierListItem::setType(type);
-    if (m_returnId == Uml::id_None)
+    if (m_returnId == Uml::ID::None)
         m_returnId = UniqueID::gen();
 }
 
@@ -195,15 +195,15 @@ UMLAttribute* UMLOperation::findParm(const QString &name)
  * @param sig       what type of operation string to show
  * @return          the string representation of the operation
  */
-QString UMLOperation::toString(Uml::SignatureType sig)
+QString UMLOperation::toString(Uml::SignatureType::Enum sig)
 {
     QString s;
 
     if (sig == Uml::SignatureType::ShowSig || sig == Uml::SignatureType::NoSig)
-          s = m_Vis.toString(true) + ' ';
+          s = Uml::Visibility::toString(m_visibility, true) + ' ';
 
     s += name();
-    Uml::ProgrammingLanguage pl = UMLApp::app()->activeLanguage();
+    Uml::ProgrammingLanguage::Enum pl = UMLApp::app()->activeLanguage();
     bool parameterlessOpNeedsParentheses =
         (pl != Uml::ProgrammingLanguage::Pascal && pl != Uml::ProgrammingLanguage::Ada);
 
@@ -452,7 +452,7 @@ void UMLOperation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
     QDomElement featureElement = qDoc.createElement( "UML:BehavioralFeature.parameter" );
     if (m_pSecondary) {
         QDomElement retElement = qDoc.createElement("UML:Parameter");
-        if (m_returnId == Uml::id_None) {
+        if (m_returnId == Uml::ID::None) {
             uDebug() << name() << ": m_returnId is not set, setting it now.";
             m_returnId = UniqueID::gen();
         }
@@ -475,10 +475,10 @@ void UMLOperation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
         }
         attElement.setAttribute( "value", pAtt->getInitialValue() );
 
-        Uml::Parameter_Direction kind = pAtt->getParmKind();
-        if (kind == Uml::pd_Out)
+        Uml::ParameterDirection::Enum kind = pAtt->getParmKind();
+        if (kind == Uml::ParameterDirection::Out)
             attElement.setAttribute("kind", "out");
-        else if (kind == Uml::pd_InOut)
+        else if (kind == Uml::ParameterDirection::InOut)
             attElement.setAttribute("kind", "inout");
         // The default for the parameter kind is "in".
 
@@ -573,11 +573,11 @@ bool UMLOperation::load( QDomElement & element )
                     return false;
                 }
                 if (kind == "out")
-                    pAtt->setParmKind(Uml::pd_Out);
+                    pAtt->setParmKind(Uml::ParameterDirection::Out);
                 else if (kind == "inout")
-                    pAtt->setParmKind(Uml::pd_InOut);
+                    pAtt->setParmKind(Uml::ParameterDirection::InOut);
                 else
-                    pAtt->setParmKind(Uml::pd_In);
+                    pAtt->setParmKind(Uml::ParameterDirection::In);
                 m_List.append( pAtt );
             }
         }
@@ -604,5 +604,4 @@ bool UMLOperation::load( QDomElement & element )
     return true;
 }
 
-
 #include "operation.moc"
