@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2010                                               *
+ *   copyright (C) 2006-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -57,7 +57,7 @@ public:
 
     enum NodeType { nt_object, nt_list };
 
-    PetalNode(NodeType nt);
+    explicit PetalNode(NodeType nt);
     virtual ~PetalNode();
 
     // getters
