@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2012                                               *
+ *   copyright (C) 2004-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -30,7 +30,7 @@ class ToolBarStateArrow : public ToolBarState
 {
     Q_OBJECT
 public:
-    ToolBarStateArrow(UMLScene *umlScene);
+    explicit ToolBarStateArrow(UMLScene *umlScene);
     virtual ~ToolBarStateArrow();
 
     virtual void init();
