@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -28,7 +28,7 @@
 DEBUG_REGISTER(UMLView)
 
 /**
- * Constructor
+ * Constructor.
  */
 UMLView::UMLView(UMLFolder *parentFolder)
   : QGraphicsView(UMLApp::app()->mainViewWidget()),
@@ -84,7 +84,7 @@ void UMLView::setZoom(int zoom)
     setMatrix(wm);
 
     m_nZoom = currentZoom();
-    umlScene()->resizeCanvasToItems();
+    umlScene()->resizeSceneToItems();
 }
 
 /**
@@ -124,13 +124,13 @@ void UMLView::zoomOut()
 }
 
 /**
- * Overrides standard method from QWidget to resize canvas when
+ * Overrides standard method from QWidget to resize scene when
  * it's shown.
  */
 void UMLView::show()
 {
     QWidget::show();
-    umlScene()->resizeCanvasToItems();
+    umlScene()->resizeSceneToItems();
 }
 
 /**
@@ -151,14 +151,14 @@ void UMLView::dragEnterEvent(QDragEnterEvent *e)
     }
     UMLDragData::LvTypeAndID * tid = tidIt.next();
     if (!tid) {
-        uDebug() << "UMLView::contentsDragEnterEvent: "
-                 << "UMLDragData::getClip3TypeAndID returned empty list";
+        DEBUG(DBG_SRC) << "UMLView::contentsDragEnterEvent: "
+                       << "UMLDragData::getClip3TypeAndID returned empty list";
         return;
     }
     UMLListViewItem::ListViewType lvtype = tid->type;
-    Uml::IDType id = tid->id;
+    Uml::ID::Type id = tid->id;
 
-    Uml::DiagramType diagramType = umlScene()->type();
+    Uml::DiagramType::Enum diagramType = umlScene()->type();
 
     UMLObject* temp = 0;
     //if dragging diagram - might be a drag-to-note
@@ -174,7 +174,7 @@ void UMLView::dragEnterEvent(QDragEnterEvent *e)
     UMLDoc *pDoc = UMLApp::app()->document();
     //make sure can find UMLObject
     if( !(temp = pDoc->findObjectById(id) ) ) {
-        kDebug() << "object " << ID2STR(id) << " not found" << endl;
+        DEBUG(DBG_SRC) << "object " << ID2STR(id) << " not found";
         e->setAccepted(false);
         return;
     }
@@ -257,12 +257,12 @@ void UMLView::dropEvent(QDropEvent *e) {
     }
     UMLDragData::LvTypeAndID * tid = tidIt.next();
     if (!tid) {
-        kDebug() << "UMLView::contentsDropEvent: "
-                  << "UMLDragData::getClip3TypeAndID returned empty list" << endl;
+        DEBUG(DBG_SRC) << "UMLView::contentsDropEvent: "
+                       << "UMLDragData::getClip3TypeAndID returned empty list";
         return;
     }
     UMLListViewItem::ListViewType lvtype = tid->type;
-    Uml::IDType id = tid->id;
+    Uml::ID::Type id = tid->id;
 
     if (Model_Utils::typeIsDiagram(lvtype)) {
         bool breakFlag = false;
@@ -283,8 +283,8 @@ void UMLView::dropEvent(QDropEvent *e) {
     UMLDoc *pDoc = UMLApp::app()->document();
     UMLObject* o = pDoc->findObjectById(id);
     if( !o ) {
-        kDebug() << "UMLView::contentsDropEvent: object id=" << ID2STR(id)
-                  << " not found" << endl;
+        DEBUG(DBG_SRC) << "UMLView::contentsDropEvent: object id=" << ID2STR(id)
+                       << " not found";
         return;
     }
     umlScene()->setCreateObject(true);
@@ -348,7 +348,6 @@ void UMLView::resizeEvent(QResizeEvent* event)
     QGraphicsView::resizeEvent(event);
 }
 
-
 /**
  * Overrides the standard operation.
  */
@@ -360,7 +359,6 @@ void UMLView::showEvent(QShowEvent* se)
     connect(tb, SIGNAL(sigButtonChanged(int)), us, SLOT(slotToolBarChanged(int)));
     connect(us, SIGNAL(sigResetToolBar()), tb, SLOT(slotResetToolBar()));
 
-
     umlScene()->showEvent(se);
     us->resetToolbar();
 }
