@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -15,10 +15,14 @@
 
 inline QByteArray umbrelloVersion()
 {
+#ifdef UMBRELLO_VERSION_STRING
+    QString versionStr = QString(UMBRELLO_VERSION_STRING);
+#else
     QString versionStr = QString("%1.%2.%3")
         .arg(KDE::versionMajor()-2)
         .arg(KDE::versionMinor())
         .arg(KDE::versionRelease());
+#endif
     return versionStr.toLatin1();
 }
 
