@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2011                                               *
+ *   copyright (C) 2003-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -45,9 +45,9 @@ ComponentWidget::~ComponentWidget()
  * Reimplemented from UMLWidget::paint to paint component
  * widget.
  */
-void ComponentWidget::paint(QPainter & p, int offsetX, int offsetY)
+void ComponentWidget::draw(QPainter & p, int offsetX, int offsetY)
 {
-    UMLComponent *umlcomp = static_cast<UMLComponent*>(m_pObject);
+    UMLComponent *umlcomp = static_cast<UMLComponent*>(m_umlObject);
     if (umlcomp == NULL)
         return;
     setPenFromSettings(p);
@@ -59,7 +59,7 @@ void ComponentWidget::paint(QPainter & p, int offsetX, int offsetY)
     if ( UMLWidget::useFillColor() ) {
         p.setBrush( UMLWidget::fillColor() );
     } else {
-        p.setBrush( m_scene->view()->viewport()->palette().color(QPalette::Background) );
+        p.setBrush( m_scene->activeView()->viewport()->palette().color(QPalette::Background) );
     }
 
     const int w = width();
@@ -69,7 +69,7 @@ void ComponentWidget::paint(QPainter & p, int offsetX, int offsetY)
     const QFontMetrics &fm = getFontMetrics(FT_BOLD);
     const int fontHeight = fm.lineSpacing();
     QString nameStr = name();
-    const QString stereotype = m_pObject->stereotype();
+    const QString stereotype = m_umlObject->stereotype();
 
     p.drawRect(offsetX + 2*COMPONENT_MARGIN, offsetY, w - 2*COMPONENT_MARGIN, h);
     p.drawRect(offsetX, offsetY + h/2 - fontHeight/2 - fontHeight, COMPONENT_MARGIN*4, fontHeight);
@@ -83,7 +83,7 @@ void ComponentWidget::paint(QPainter & p, int offsetX, int offsetY)
     if (!stereotype.isEmpty()) {
         p.drawText(offsetX + (COMPONENT_MARGIN*4), offsetY + (h/2) - fontHeight,
                    w - (COMPONENT_MARGIN*4), fontHeight, Qt::AlignCenter,
-                   m_pObject->stereotype(true));
+                   m_umlObject->stereotype(true));
         lines = 2;
     }
 
@@ -121,13 +121,13 @@ void ComponentWidget::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
  */
 UMLSceneSize ComponentWidget::minimumSize()
 {
-    if ( !m_pObject) {
+    if ( !m_umlObject) {
         return UMLSceneSize(70, 70);
     }
     const QFontMetrics &fm = getFontMetrics(FT_BOLD_ITALIC);
     const int fontHeight = fm.lineSpacing();
 
-    QString name = m_pObject->name();
+    QString name = m_umlObject->name();
     if ( UMLWidget::isInstance() ) {
         name = UMLWidget::instanceName() + " : " + name;
     }
@@ -135,8 +135,8 @@ UMLSceneSize ComponentWidget::minimumSize()
     int width = fm.width(name);
 
     int stereoWidth = 0;
-    if (!m_pObject->stereotype().isEmpty()) {
-        stereoWidth = fm.width(m_pObject->stereotype(true));
+    if (!m_umlObject->stereotype().isEmpty()) {
+        stereoWidth = fm.width(m_umlObject->stereotype(true));
     }
     if (stereoWidth > width)
         width = stereoWidth;
