@@ -4,16 +4,13 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2011                                               *
+ *   copyright (C) 2003-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "datatypewidget.h"
 
-// qt/kde includes
-#include <QtGui/QPainter>
-
 // app includes
 #include "classifier.h"
 #include "classifierlistitem.h"
@@ -22,14 +19,16 @@
 #include "umldoc.h"
 #include "umlview.h"
 
-#define CIRCLE_SIZE 30
+// qt includes
+#include <QPainter>
 
+#define CIRCLE_SIZE 30
 
 /**
  * Constructs an DatatypeWidget.
  *
- * @param scene              The parent of this DatatypeWidget.
- * @param d         The UMLClassifier this will be representing.
+ * @param scene   The parent of this DatatypeWidget.
+ * @param d       The UMLClassifier this will be representing.
  */
 DatatypeWidget::DatatypeWidget(UMLScene *scene, UMLClassifier *d) 
   : UMLWidget(scene, WidgetBase::wt_Datatype, d)
@@ -47,13 +46,13 @@ DatatypeWidget::~DatatypeWidget()
 /**
  * Overrides standard method.
  */
-void DatatypeWidget::paint(QPainter& p, int offsetX, int offsetY)
+void DatatypeWidget::draw(QPainter& p, int offsetX, int offsetY)
 {
     setPenFromSettings(p);
     if (UMLWidget::useFillColor())  {
         p.setBrush(UMLWidget::fillColor());
     } else {
-        p.setBrush( m_scene->view()->viewport()->palette().color(QPalette::Background) );
+        p.setBrush( m_scene->activeView()->viewport()->palette().color(QPalette::Background) );
     }
 
     int w = width();
@@ -70,9 +69,9 @@ void DatatypeWidget::paint(QPainter& p, int offsetX, int offsetY)
     p.setFont(font);
     p.drawText(offsetX + DATATYPE_MARGIN, offsetY,
                w - DATATYPE_MARGIN* 2,fontHeight,
-               Qt::AlignCenter, m_pObject->stereotype(true));
+               Qt::AlignCenter, m_umlObject->stereotype(true));
 
-    font.setItalic( m_pObject->isAbstract() );
+    font.setItalic( m_umlObject->isAbstract() );
     p.setFont(font);
     p.drawText(offsetX + DATATYPE_MARGIN, offsetY + fontHeight,
                w - DATATYPE_MARGIN * 2, fontHeight, Qt::AlignCenter, name());
@@ -105,7 +104,7 @@ void DatatypeWidget::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
  */
 UMLSceneSize DatatypeWidget::minimumSize()
 {
-    if (!m_pObject)  {
+    if (!m_umlObject)  {
         return UMLWidget::minimumSize();
     }
     int width, height;
@@ -121,8 +120,8 @@ UMLSceneSize DatatypeWidget::minimumSize()
     //now set the width of the concept
     //set width to name to start with
     //set width to name to start with
-    width = getFontMetrics(FT_BOLD_ITALIC).boundingRect(m_pObject->fullyQualifiedName()).width();
-    int w = getFontMetrics(FT_BOLD).boundingRect(m_pObject->stereotype(true)).width();
+    width = getFontMetrics(FT_BOLD_ITALIC).boundingRect(m_umlObject->fullyQualifiedName()).width();
+    int w = getFontMetrics(FT_BOLD).boundingRect(m_umlObject->stereotype(true)).width();
 
     width = w > width?w:width;
 
