@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2011                                               *
+ *   copyright (C) 2004-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -101,7 +101,7 @@ public:
      */
     virtual void constrainTextPos(UMLSceneValue &textX, UMLSceneValue &textY,
                                   UMLSceneValue textWidth, UMLSceneValue textHeight,
-                                  Uml::TextRole tr) = 0;
+                                  Uml::TextRole::Enum tr) = 0;
 
     virtual void calculateNameTextSegment();
 
