@@ -35,9 +35,13 @@
 
 DEBUG_REGISTER_DISABLED(MessageWidget)
 
+static const int circleWidth = 10;
+
 /**
  * Constructs a MessageWidget.
  *
+ * This method is used for creation, synchronous and synchronous message types.
+ *
  * @param scene   The parent to this class.
  * @param a       The role A widget for this message.
  * @param b       The role B widget for this message.
@@ -140,14 +144,30 @@ MessageWidget::~MessageWidget()
 {
 }
 
+/**
+ * Sets the y-coordinate.
+ * Reimplemented from UMLWidget.
+ *
+ * @param y The y-coordinate to be set.
+ */
+void MessageWidget::setY(UMLSceneValue y)
+{
+    UMLWidget::setY(y);
+    m_nY = y;
+    if (m_sequenceMessageType == Uml::SequenceMessage::Creation) {
+        const UMLSceneValue objWidgetHalfHeight = m_pOw[Uml::RoleType::B]->height() / 2;
+        m_pOw[Uml::RoleType::B]->setY(y - objWidgetHalfHeight);
+    }
+    moveEvent(0);
+}
+
 /**
  * Update the UMLWidget::m_resizable flag according to the
  * charactersitics of this message.
  */
 void MessageWidget::updateResizability()
 {
-    if (m_sequenceMessageType == Uml::SequenceMessage::Synchronous ||
-        m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B])
+    if (m_sequenceMessageType == Uml::SequenceMessage::Synchronous)
         UMLWidget::m_resizable = true;
     else
         UMLWidget::m_resizable = false;
@@ -202,16 +222,18 @@ void MessageWidget::drawSolidArrowhead(QPainter& p, int x, int y, Qt::ArrowType
 void MessageWidget::drawArrow(QPainter& p, int x, int y, int w,
                               Qt::ArrowType direction, bool useDottedLine /* = false */)
 {
-    int arrowheadStartX = x;
-    int arrowheadExtentX = 4;
-    if (direction == Qt::RightArrow) {
-        arrowheadStartX += w;
-        arrowheadExtentX = -arrowheadExtentX;
+    if (w > 3) {
+        int arrowheadStartX = x;
+        int arrowheadExtentX = 4;
+        if (direction == Qt::RightArrow) {
+            arrowheadStartX += w;
+            arrowheadExtentX = -arrowheadExtentX;
+        }
+        // draw upper half of arrowhead
+        p.drawLine(arrowheadStartX, y, arrowheadStartX + arrowheadExtentX, y - 3);
+        // draw lower half of arrowhead
+        p.drawLine(arrowheadStartX, y, arrowheadStartX + arrowheadExtentX, y + 3);
     }
-    // draw upper half of arrowhead
-    p.drawLine(arrowheadStartX, y, arrowheadStartX + arrowheadExtentX, y - 3);
-    // draw lower half of arrowhead
-    p.drawLine(arrowheadStartX, y, arrowheadStartX + arrowheadExtentX, y + 3);
     // draw arrow line
     if (useDottedLine) {
         QPen pen = p.pen();
@@ -234,12 +256,15 @@ void MessageWidget::drawSynchronous(QPainter& p, int offsetX, int offsetY)
     int h = height();
 
     bool messageOverlaps = m_pOw[Uml::RoleType::A]->messageOverlap( y(), this );
+    const int boxWidth = 17;
+    const int wr = w < boxWidth ? w : boxWidth;
+    const int arrowWidth = 4;
 
-    if(m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B]) {
-        p.fillRect( offsetX, offsetY, 17, h,  QBrush(Qt::white) );              //box
-        p.drawRect(offsetX, offsetY, 17, h);                                    //box
-        offsetX += 17;
-        w -= 17;
+    if(isSelf()) {
+        p.fillRect( offsetX, offsetY, wr, h,  QBrush(Qt::white) );              //box
+        p.drawRect(offsetX, offsetY, wr, h);                                    //box
+        offsetX += wr;
+        w -= wr;
         offsetY += 3;
         const int lowerLineY = offsetY + h - 6;
         // draw upper line segment (leaving the life line)
@@ -248,7 +273,7 @@ void MessageWidget::drawSynchronous(QPainter& p, int offsetX, int offsetY)
         p.drawLine(offsetX + w, offsetY, offsetX + w, lowerLineY);
         // draw lower line segment (back to the life line)
         drawArrow(p, offsetX, lowerLineY, w, Qt::LeftArrow);
-        offsetX -= 17;
+        offsetX -= wr;
         offsetY -= 3;
     } else if(x1 < x2) {
         if (messageOverlaps)  {
@@ -256,12 +281,13 @@ void MessageWidget::drawSynchronous(QPainter& p, int offsetX, int offsetY)
             w -= 8;
         }
         QPen pen = p.pen();
-        int startX = offsetX + w - 16;
-        p.fillRect(startX, offsetY, 17, h,  QBrush(Qt::white));         //box
-        p.drawRect(startX, offsetY, 17, h);                             //box
-        p.drawLine(offsetX, offsetY + 4, startX, offsetY + 4);          //arrow line
-        drawSolidArrowhead(p, startX - 1, offsetY + 4, Qt::RightArrow);
-        drawArrow(p, offsetX, offsetY + h - 3, w - 16, Qt::LeftArrow, true); // return arrow
+        int startX = offsetX + w - wr + 1;
+        p.fillRect(startX, offsetY, wr, h,  QBrush(Qt::white));         //box
+        p.drawRect(startX, offsetY, wr, h);                             //box
+        p.drawLine(offsetX, offsetY + arrowWidth, startX, offsetY + arrowWidth);          //arrow line
+        if (w > boxWidth + arrowWidth)
+            drawSolidArrowhead(p, startX - 1, offsetY + arrowWidth, Qt::RightArrow);
+        drawArrow(p, offsetX, offsetY + h - arrowWidth + 1, w - wr + 1, Qt::LeftArrow, true); // return arrow
         if (messageOverlaps)  {
             offsetX -= 8; //reset for drawSelected()
         }
@@ -270,11 +296,12 @@ void MessageWidget::drawSynchronous(QPainter& p, int offsetX, int offsetY)
             w -=8;
         }
         QPen pen = p.pen();
-        p.fillRect( offsetX, offsetY, 17, h,  QBrush(Qt::white) );              //box
-        p.drawRect(offsetX, offsetY, 17, h);                                    //box
-        p.drawLine(offsetX + 18, offsetY + 4, offsetX + w, offsetY + 4);        //arrow line
-        drawSolidArrowhead(p, offsetX + 17, offsetY + 4, Qt::LeftArrow);
-        drawArrow(p, offsetX + 18, offsetY + h - 3, w - 18, Qt::RightArrow, true); // return arrow
+        p.fillRect( offsetX, offsetY, wr, h,  QBrush(Qt::white) );              //box
+        p.drawRect(offsetX, offsetY, wr, h);                                    //box
+        p.drawLine(offsetX + wr + 1, offsetY + arrowWidth, offsetX + w, offsetY + arrowWidth);    //arrow line
+        if (w > boxWidth + arrowWidth)
+            drawSolidArrowhead(p, offsetX + wr, offsetY + arrowWidth, Qt::LeftArrow);
+        drawArrow(p, offsetX + wr + 1, offsetY + h - arrowWidth + 1, w - wr - 1, Qt::RightArrow, true); // return arrow
     }
 
     if(m_selected) {
@@ -294,7 +321,7 @@ void MessageWidget::drawAsynchronous(QPainter& p, int offsetX, int offsetY)
     bool messageOverlapsA = m_pOw[Uml::RoleType::A] -> messageOverlap( y(), this );
     //bool messageOverlapsB = m_pOw[Uml::RoleType::B] -> messageOverlap( y(), this );
 
-    if(m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B]) {
+    if(isSelf()) {
         if (messageOverlapsA)  {
             offsetX += 7;
             w -= 7;
@@ -338,7 +365,7 @@ void MessageWidget::drawCreation(QPainter& p, int offsetX, int offsetY)
 {
     int x1 = m_pOw[Uml::RoleType::A]->x();
     int x2 = m_pOw[Uml::RoleType::B]->x();
-    int w = width() - 1;
+    int w = width();
     //int h = height() - 1;
     bool messageOverlapsA = m_pOw[Uml::RoleType::A]->messageOverlap( y(), this );
     //bool messageOverlapsB = m_pOw[Uml::RoleType::B]->messageOverlap( y(), this );
@@ -371,14 +398,10 @@ void MessageWidget::drawCreation(QPainter& p, int offsetX, int offsetY)
  */
 void MessageWidget::drawLost(QPainter& p, int offsetX, int offsetY)
 {
-    int x1 = m_pOw[Uml::RoleType::A]->x();
+    int x1 = m_pOw[Uml::RoleType::A]->centerX();
     int x2 = xclicked;
-    int w1 = m_pOw[Uml::RoleType::A]->width() / 2;
-    x1 += w1;
-
-    int w = width() ;
-
-    int h = 10;
+    int w = width();
+    int h = height();
     bool messageOverlapsA = m_pOw[Uml::RoleType::A] -> messageOverlap( y(), this );
     //bool messageOverlapsB = m_pOw[Uml::RoleType::B] -> messageOverlap( y(), this );
 
@@ -390,8 +413,8 @@ void MessageWidget::drawLost(QPainter& p, int offsetX, int offsetY)
 
         setPenFromSettings(p);
         p.setBrush( WidgetBase::lineColor() );
-        p.drawEllipse(x1 + w - h , offsetY - h/2, h, h);
-        drawArrow(p,offsetX, offsetY, w - h, Qt::RightArrow);
+        p.drawEllipse(offsetX + w - h, offsetY, h, h);
+        drawArrow(p,offsetX, offsetY + h/2, w - h, Qt::RightArrow);
 
         if (messageOverlapsA)  {
             offsetX -= 7;
@@ -399,8 +422,8 @@ void MessageWidget::drawLost(QPainter& p, int offsetX, int offsetY)
     } else      {
         setPenFromSettings(p);
         p.setBrush( WidgetBase::lineColor() );
-        p.drawEllipse(offsetX, offsetY - h/2, h, h);
-        drawArrow(p, offsetX + h, offsetY, w - h, Qt::LeftArrow);
+        p.drawEllipse(offsetX, offsetY, h, h);
+        drawArrow(p, offsetX + h, offsetY + h/2, w - h, Qt::LeftArrow);
     }
 
     if (m_selected)
@@ -412,11 +435,10 @@ void MessageWidget::drawLost(QPainter& p, int offsetX, int offsetY)
  */
 void MessageWidget::drawFound(QPainter& p, int offsetX, int offsetY)
 {
-    int x1 = m_pOw[Uml::RoleType::A]->x();
+    int x1 = m_pOw[Uml::RoleType::A]->centerX();
     int x2 = xclicked;
-    int w = width() ;
-
-    int h = 10;
+    int w = width();
+    int h = height();
     bool messageOverlapsA = m_pOw[Uml::RoleType::A] -> messageOverlap( y(), this );
     //bool messageOverlapsB = m_pOw[Uml::RoleType::B] -> messageOverlap( y(), this );
 
@@ -427,8 +449,8 @@ void MessageWidget::drawFound(QPainter& p, int offsetX, int offsetY)
         }
         setPenFromSettings(p);
         p.setBrush( WidgetBase::lineColor() );
-        p.drawEllipse(x2, offsetY - h/2, h, h);
-        drawArrow(p, x2 - w + h, offsetY, w, Qt::LeftArrow);
+        p.drawEllipse(offsetX + w - h, offsetY, h, h);
+        drawArrow(p, offsetX, offsetY + h/2, w, Qt::LeftArrow);
         if (messageOverlapsA)  {
             offsetX -= 7;
         }
@@ -438,8 +460,8 @@ void MessageWidget::drawFound(QPainter& p, int offsetX, int offsetY)
         }
         setPenFromSettings(p);
         p.setBrush( WidgetBase::lineColor() );
-        p.drawEllipse(x2, offsetY - h/2, h, h);
-        drawArrow(p, x2, offsetY, w, Qt::RightArrow);
+        p.drawEllipse(offsetX, offsetY, h, h);
+        drawArrow(p, offsetX, offsetY + h/2, w, Qt::RightArrow);
     }
 
     if (m_selected)
@@ -514,7 +536,7 @@ int MessageWidget::constrainX(int textX, int textWidth, Uml::TextRole::Enum tr)
             objectAtRight = m_pOw[Uml::RoleType::B];
         else
             objectAtRight = m_pOw[Uml::RoleType::A];
-        const int objRight_seqLineX = objectAtRight->x() + objectAtRight->width() / 2;
+        const int objRight_seqLineX = objectAtRight->centerX();
         const int maxTextX = objRight_seqLineX - textWidth - 5;
         if (maxTextX <= minTextX)
             result = minTextX;
@@ -591,7 +613,7 @@ void MessageWidget::calculateWidget()
     setVisible(true);
 
     setX(m_nPosX);
-    setY(m_nY);
+    UMLWidget::setY(m_nY);
 }
 
 void MessageWidget::slotWidgetMoved(Uml::ID::Type id)
@@ -630,6 +652,19 @@ bool MessageWidget::hasObjectWidget(ObjectWidget * w)
         return false;
 }
 
+/**
+ * This method determines whether the message is for "Self" for
+ * an ObjectWidget.
+ *
+ * @retval True If both ObjectWidgets for this widget exists and
+ *              are same.
+ */
+bool MessageWidget::isSelf() const
+{
+    return (m_pOw[Uml::RoleType::A] && m_pOw[Uml::RoleType::B] &&
+            m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B]);
+}
+
 void MessageWidget::slotMenuSelection(QAction* action)
 {
     ListPopupMenu::MenuType sel = m_pMenu->getMenuType(action);
@@ -692,7 +727,7 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
 
     if( !m_pFText ) {
         Uml::TextRole::Enum tr = Uml::TextRole::Seq_Message;
-        if (m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B])
+        if (isSelf())
             tr = Uml::TextRole::Seq_Message_Self;
         m_pFText = new FloatingTextWidget( m_scene, tr, "" );
         m_pFText->setFont(UMLWidget::font());
@@ -711,7 +746,8 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
     connect(this, SIGNAL(sigMessageMoved()), m_pOw[Uml::RoleType::A], SLOT(slotMessageMoved()) );
     connect(this, SIGNAL(sigMessageMoved()), m_pOw[Uml::RoleType::B], SLOT(slotMessageMoved()) );
     m_pOw[Uml::RoleType::A] -> messageAdded(this);
-    m_pOw[Uml::RoleType::B] -> messageAdded(this);
+    if (!isSelf())
+        m_pOw[Uml::RoleType::B] -> messageAdded(this);
     calculateDimensions();
 
     emit sigMessageMoved();
@@ -886,16 +922,12 @@ void MessageWidget::calculateDimensionsSynchronous()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::RoleType::A]->x();
-    int x2 = m_pOw[Uml::RoleType::B]->x();
-    int w1 = m_pOw[Uml::RoleType::A]->width() / 2;
-    int w2 = m_pOw[Uml::RoleType::B]->width() / 2;
-    x1 += w1;
-    x2 += w2;
+    int x1 = m_pOw[Uml::RoleType::A]->centerX();
+    int x2 = m_pOw[Uml::RoleType::B]->centerX();
 
     int widgetWidth = 0;
     int widgetHeight = 0;
-    if( m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B] ) {
+    if(isSelf()) {
         widgetWidth = 50;
         x = x1 - 2;
     } else if( x1 < x2 ) {
@@ -923,16 +955,12 @@ void MessageWidget::calculateDimensionsAsynchronous()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::RoleType::A]->x();
-    int x2 = m_pOw[Uml::RoleType::B]->x();
-    int w1 = m_pOw[Uml::RoleType::A]->width() / 2;
-    int w2 = m_pOw[Uml::RoleType::B]->width() / 2;
-    x1 += w1;
-    x2 += w2;
+    int x1 = m_pOw[Uml::RoleType::A]->centerX();
+    int x2 = m_pOw[Uml::RoleType::B]->centerX();
 
     int widgetWidth = 0;
     int widgetHeight = 8;
-    if( m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B] ) {
+    if(isSelf()) {
         widgetWidth = 50;
         x = x1;
         if( height() < 20 ) {
@@ -960,11 +988,10 @@ void MessageWidget::calculateDimensionsCreation()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::RoleType::A]->x();
+    int x1 = m_pOw[Uml::RoleType::A]->centerX();
     int x2 = m_pOw[Uml::RoleType::B]->x();
-    int w1 = m_pOw[Uml::RoleType::A]->width() / 2;
     int w2 = m_pOw[Uml::RoleType::B]->width();
-    x1 += w1;
+
     if (x1 > x2)
         x2 += w2;
 
@@ -991,22 +1018,18 @@ void MessageWidget::calculateDimensionsLost()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::RoleType::A]->x();
+    int x1 = m_pOw[Uml::RoleType::A]->centerX();
     int x2 = xclicked;
-    int w1 = m_pOw[Uml::RoleType::A]->width() / 2;
-
-    x1 += w1;
 
     int widgetWidth = 0;
     int widgetHeight = 10;
     if( x1 < x2 ) {
         x = x1;
-        widgetWidth = x2 - x1 + widgetHeight;
+        widgetWidth = x2 - x1 + circleWidth/2;
     } else {
-        x = x2;
-        widgetWidth = x1 - x2;
+        x = x2 - circleWidth/2;
+        widgetWidth = x1 - x2 + circleWidth/2;
     }
-    x += 1;
     m_nPosX = x;
     setSize(widgetWidth, widgetHeight);
 }
@@ -1018,22 +1041,18 @@ void MessageWidget::calculateDimensionsFound()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::RoleType::A]->x();
+    int x1 = m_pOw[Uml::RoleType::A]->centerX();
     int x2 = xclicked;
-    int w1 = m_pOw[Uml::RoleType::A]->width() / 2;
-    x1 += w1;
-
 
     int widgetWidth = 0;
     int widgetHeight = 10;
     if( x1 < x2 ) {
         x = x1;
-        widgetWidth = x2 - x1 + widgetHeight;
+        widgetWidth = x2 - x1 + circleWidth/2;
     } else {
-        x = x2 ;
-        widgetWidth = x1 - x2;
+        x = x2 - circleWidth/2;
+        widgetWidth = x1 - x2 + circleWidth/2;
     }
-    x += 1;
 
     m_nPosX = x;
     setSize(widgetWidth, widgetHeight);
@@ -1211,6 +1230,7 @@ bool MessageWidget::loadFromXMI(QDomElement& qElement)
     m_widgetAId = STR2ID(widgetaid);
     m_widgetBId = STR2ID(widgetbid);
     m_textId = STR2ID(textid);
+    m_nY = y();
 
     Uml::TextRole::Enum tr = Uml::TextRole::Seq_Message;
     if (m_widgetAId == m_widgetBId)
