@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2011                                               *
+ *   copyright (C) 2004-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -24,7 +24,7 @@ class ToolBarStateOneWidget : public ToolBarStatePool
 {
     Q_OBJECT
 public:
-    ToolBarStateOneWidget(UMLScene *umlScene);
+    explicit ToolBarStateOneWidget(UMLScene *umlScene);
     virtual ~ToolBarStateOneWidget();
 
     virtual void cleanBeforeChange();
